M3EAppBar class

A Material 3 Expressive app bar with top, bottom, and sliver variants.

Inheritance
Implemented types

Constructors

M3EAppBar.bottom({Key? key, List<Widget>? actions = const <Widget>[], Widget? floatingActionButton, bool safeArea = true})
A bottom app bar with actions and an optional floating action button.
const
M3EAppBar.search({Key? key, required M3ESearchController searchController, required M3ESearchSuggestionsBuilder suggestionsBuilder, Widget? leading, List<Widget>? actions, bool centerTitle = false, String? barHintText, Widget? barLeading, Iterable<Widget>? barTrailing, WidgetStateProperty<Color?>? barBackgroundColor, bool isFullScreen = true, Color? backgroundColor, Color? foregroundColor, double? elevation, M3EAppBarShapeFamily shapeFamily = M3EAppBarShapeFamily.square, M3EAppBarDensity density = M3EAppBarDensity.regular, double? toolbarHeight, bool automaticallyImplyLeading = false, bool safeArea = true, Clip clipBehavior = Clip.none, String? semanticLabel, ValueChanged<String>? onSubmitted, ValueChanged<String>? onChanged, VoidCallback? onClose, VoidCallback? onOpen, BoxConstraints? searchConstraints})
A top app bar whose title is a read-only anchored M3ESearchAnchor.bar.
factory
M3EAppBar.sliver({Key? key, Widget? leading, Widget? title, String? titleText, List<Widget>? actions, bool centerTitle = false, Color? backgroundColor, Color? foregroundColor, bool pinned = true, bool floating = false, bool snap = false, M3EAppBarShapeFamily shapeFamily = M3EAppBarShapeFamily.round, M3EAppBarDensity density = M3EAppBarDensity.regular, M3EAppBarVariant variant = M3EAppBarVariant.medium, String? semanticLabel})
A scrolling sliver app bar for use in CustomScrollView.slivers.
const
M3EAppBar.top({Key? key, Widget? leading, Widget? title, String? titleText, List<Widget>? actions, bool centerTitle = false, Color? backgroundColor, Color? foregroundColor, double? elevation, M3EAppBarShapeFamily shapeFamily = M3EAppBarShapeFamily.square, M3EAppBarDensity density = M3EAppBarDensity.regular, double? toolbarHeight, bool automaticallyImplyLeading = false, bool safeArea = true, Clip clipBehavior = Clip.none, String? semanticLabel})
A fixed top app bar for use in Scaffold.appBar.
const

Properties

actions List<Widget>?
actions.
final
automaticallyImplyLeading bool
automaticallyImplyLeading.
final
backgroundColor Color?
backgroundColor.
final
centerTitle bool
centerTitle.
final
clipBehavior Clip
clipBehavior.
final
density M3EAppBarDensity
density.
final
elevation double?
elevation.
final
floating bool
floating.
final
floatingActionButton Widget?
floatingActionButton.
final
foregroundColor Color?
foregroundColor.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading Widget?
leading.
final
pinned bool
pinned.
final
preferredSize Size
The size this widget would prefer if it were otherwise unconstrained.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safeArea bool
When true, applies MediaQuery.viewPadding on the docked edge only (top for M3EAppBar.top/M3EAppBar.search, bottom for M3EAppBar.bottom).
final
semanticLabel String?
semanticLabel.
final
shapeFamily M3EAppBarShapeFamily
shapeFamily.
final
snap bool
snap.
final
title Widget?
title.
final
titleText String?
titleText.
final
toolbarHeight double?
toolbarHeight.
final
variant M3EAppBarVariant
variant.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited