components/bottom_sheets/controllers/m3e_bottom_sheet_scroll_controller library
Classes
- M3EBottomSheetDragTarget
- Sheet that an inner scroll view hands drags to.
- M3EBottomSheetScrollController
- Scroll controller that resizes the sheet before scrolling its content.