M3EBottomSheetStrings class abstract final

Default English strings for bottom sheets.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

close → const String
Close action.
collapse → const String
Collapse action.
collapsed → const String
Collapsed height value.
dismiss → const String
Dismiss action.
dragHandle → const String
Drag handle label.
expand → const String
Expand action.
expanded → const String
Expanded height value.
fullScreen → const String
Full-screen height value.
preview → const String
Preview height value.