components/bottom_sheets/utils/m3e_bottom_sheet_spring library

Functions

m3eBottomSheetSpring(M3ESpring spring, {required double from, required double to, double velocity = 0}) → SpringSimulation
Spring simulation from from to to for bottom sheet motion.
m3eBottomSheetSpringSettle(M3ESpring spring) → Duration
Time a 0→1 spring needs to settle (capped at 2s).