M3EButtonGroupOverflow enum

How the group handles actions that do not fit the available main-axis space.

Inheritance
Available extensions

Values

none → const M3EButtonGroupOverflow

Clip / overflow without a special strategy (content may exceed bounds).

scroll → const M3EButtonGroupOverflow

Scroll along the main axis when constraints are bounded.

Collapse trailing actions into an overflow menu trigger.

experimentalPaging → const M3EButtonGroupOverflow

Shift a visible paging window with back/forward overflow triggers.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<M3EButtonGroupOverflow>
A constant List of the values in this enum, in order of their declaration.