M3EButtonShape enum
Overall corner-radius strategy for buttons.
Used by M3EButton and M3EButtonGroup to control the button's corner radius. round produces a pill shape, while square uses the token-defined radius for the current size.
See also:
- M3EButton for the standard button widget
- M3EButtonGroup for the connected toggle button group
Values
- round → const M3EButtonShape
-
Fully round pill shape (
height / 2). - square → const M3EButtonShape
-
Square corners using the token radius for the current size.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
M3EButtonShape> - A constant List of the values in this enum, in order of their declaration.