M3EButtonStyle enum

Visual styles for M3EButton and M3EToggleButton.

See also:

Inheritance
Available extensions

Values

filled → const M3EButtonStyle

Solid background, high prominence.

outlined → const M3EButtonStyle

Transparent background with a visible border.

text → const M3EButtonStyle

No background or border, lowest prominence.

elevated → const M3EButtonStyle

Surface-colored background with a shadow.

tonal → const M3EButtonStyle

Subdued background color, medium prominence.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<M3EButtonStyle>
A constant List of the values in this enum, in order of their declaration.