M3EButtonMeasurements class

Resolved layout measurements for a button size variant.

Annotations

Constructors

M3EButtonMeasurements({required double height, required double hPadding, required double iconSize, required double iconGap})
M3EButtonMeasurements.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
height.
final
hPadding double
hPadding.
final
iconGap double
iconGap.
final
iconSize double
iconSize.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyCustomSize(M3EButtonSize? custom) M3EButtonMeasurements
applyCustomSize.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited