M3ECardControllerClient class abstract
Implemented by the card that owns an open container transform.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTransformOpen → bool
-
Whether the container transform route is open.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
closeTransform(
) → void - Reverses the container transform.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openTransform<
T extends Object?> ({WidgetBuilder? builder}) → Future< T?> -
Morphs the card into
builder, or the card's open builder. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited