variedItemExtents property
Main-axis extents for a multi-aspect carousel.
When set, animateToItem scrolls by these extents instead of a weighted carousel position.
Implementation
List<double>? variedItemExtents;
Main-axis extents for a multi-aspect carousel.
When set, animateToItem scrolls by these extents instead of a weighted carousel position.
List<double>? variedItemExtents;