consumeMaxWeight property
Whether the collapsed items are allowed to expand to the max size.
Defaults to true.
Implementation
final bool consumeMaxWeight;
Whether the collapsed items are allowed to expand to the max size.
Defaults to true.
final bool consumeMaxWeight;