controller property

M3ECarouselController? controller
final

An object that can be used to control the position to which this scroll view is scrolled.

Implementation

final M3ECarouselController? controller;