itemExtent property
The extent the children are forced to have in the main axis.
This is required for M3ECarouselView. In M3ECarouselView.weighted, this is null.
Implementation
final double? itemExtent;
The extent the children are forced to have in the main axis.
This is required for M3ECarouselView. In M3ECarouselView.weighted, this is null.
final double? itemExtent;