leadingInset property
Empty space before the first item. It scrolls away and does not change item sizes.
Implementation
final double leadingInset;
Empty space before the first item. It scrolls away and does not change item sizes.
final double leadingInset;