onChange property
Called when the leading or focal item index changes.
Implementation
final ValueChanged<M3ECarouselChangeDetails>? onChange;
Called when the leading or focal item index changes.
final ValueChanged<M3ECarouselChangeDetails>? onChange;