freeScroll property
True if item canvas movements can glide smoothly without forcing standard snap boundary stops.
Implementation
final bool freeScroll;
True if item canvas movements can glide smoothly without forcing standard snap boundary stops.
final bool freeScroll;