height property
The explicit bounded height allocation applied to the root carousel container wrapper.
Implementation
final double? height;
The explicit bounded height allocation applied to the root carousel container wrapper.
final double? height;