isExtended property
Flag indicating whether item bounding sizes shift into altered or expanded aspect footprints.
Implementation
final bool isExtended;
Flag indicating whether item bounding sizes shift into altered or expanded aspect footprints.
final bool isExtended;