scrollAnimationDuration property
The total lifespan millisecond count allocated to complete layout transition slide curves.
Implementation
final int scrollAnimationDuration;
The total lifespan millisecond count allocated to complete layout transition slide curves.
final int scrollAnimationDuration;