singleSwipeGestureSensitivityRange property
The dimensional drag delta requirement needed to trigger single-item sweep navigation actions.
Implementation
final int singleSwipeGestureSensitivityRange;
The dimensional drag delta requirement needed to trigger single-item sweep navigation actions.
final int singleSwipeGestureSensitivityRange;