M3ECarouselLayout class abstract final

Turns a weight pattern into slot sizes that follow the carousel spec.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

clampWeights({required List<int> pattern, required double viewport, required double smallMin, required double smallMax, required double largeMax}) → List<int>
Clamps small slots to smallMin–smallMax and large slots to largeMax.