M3ECheckbox class
A Material 3 Expressive checkbox.
Supports the binary and, when tristate is enabled, the indeterminate state. A 40dp state layer surrounds the 18dp box, the container color and check mark animate on change, and an error flavour is available.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- M3ECheckbox
Constructors
-
M3ECheckbox({required bool? value, required ValueChanged<
bool?> ? onChanged, bool tristate = false, bool error = false, FocusNode? focusNode, bool autofocus = false, String? semanticLabel, Key? key}) -
M3ECheckbox.
const
Properties
- autofocus → bool
-
autofocus.
final
- error → bool
-
error.
final
- focusNode → FocusNode?
-
focusNode.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onChanged
→ ValueChanged<
bool?> ? -
Called with the next value, or null to disable the checkbox.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
semanticLabel.
final
- tristate → bool
-
tristate.
final
- value → bool?
-
The current value. Null represents the indeterminate state.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited