M3EChipTheme class

Theme values for M3EChip.

Inheritance
Annotations

Constructors

M3EChipTheme({double height = 32, double iconSize = 18, double labelStartPadding = 16, double iconStartPadding = 8, double endPadding = 12, double iconLabelGap = 8})
M3EChipTheme.
const

Properties

borderRadius BorderRadius
The borderRadius.
no setter
endPadding double
endPadding.
final
hashCode int
The hash code for this object.
no setterinherited
height double
height.
final
iconLabelGap double
iconLabelGap.
final
iconSize double
iconSize.
final
iconStartPadding double
iconStartPadding.
final
labelStartPadding double
labelStartPadding.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape ShapeBorder
The shape.
no setter

Methods

containerColor(M3EColorScheme scheme, {required bool enabled, required bool selected, required bool elevated, required M3EChipType type}) Color
containerColor.
copyWith({double? height, double? iconSize, double? labelStartPadding, double? iconStartPadding, double? endPadding, double? iconLabelGap}) M3EChipTheme
Returns a copy with non-null fields replaced.
override
foregroundColor(M3EColorScheme scheme, {required bool enabled, required bool selected}) Color
foregroundColor.
lerp(M3EChipTheme? other, double t) M3EChipTheme
Linearly interpolates between this theme and other.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaults → const M3EChipTheme
defaults.