components/date_pickers/m3e_date_pickers library

Classes

M3ECalendarDatePicker
Embeddable calendar for selecting a single date.
M3ECalendarDateRangePicker
Calendar for selecting a date range.
M3ECalendarLabels
Static English labels and helpers for the calendar grid.
M3EDatePicker
Entry points for presenting M3E date picker dialogs.
M3EDatePickerActions
Cancel and confirm actions for date picker dialogs.
M3EDatePickerConstants
Layout constants for M3E date picker dialogs and calendars.
M3EDatePickerDialog
Dialog for picking a single date.
M3EDatePickerEntryModeButton
Icon button that switches date picker entry mode.
M3EDatePickerHeader
Header for single- and range-date picker dialogs.
M3EDatePickerTheme
Theme values for M3E date pickers.
M3EDatePickerUtils
Date helpers shared by calendar, input, and dialog pickers.
M3EDateRange
A selected date range with optional end.
M3EDateRangePickerDialog
Dialog for picking a date range.
M3EDayPicker
Weekday headers and day grid for one month.
M3EInputDatePickerFormField
Text field for entering a single date in a picker dialog.
M3EInputDateRangePickerFormField
Text fields for entering a date range in a picker dialog.
M3EMonthPicker
Month navigation with a PageView of day grids.
M3EYearPicker
Scrollable year grid for calendar date pickers.

Typedefs

M3ESelectableDayForRangePredicate = bool Function(DateTime day)
Returns true when day can be selected in a range picker.
M3ESelectableDayPredicate = bool Function(DateTime day)
Returns true when day can be selected in a single-date picker.