M3EDateRange class

A selected date range with optional end.

Annotations

Constructors

M3EDateRange({required DateTime start, DateTime? end})
M3EDateRange.
const

Properties

end DateTime?
end.
final
hashCode int
The hash code for this object.
no setteroverride
isComplete bool
The isComplete.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime
start.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override