M3EDatePickerUtils class abstract final

Date helpers shared by calendar, input, and dialog pickers.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

addMonthsToMonthDate(DateTime monthDate, int delta) DateTime
addMonthsToMonthDate.
calendarDayViewHeight(DateTime month, int firstDayOfWeekIndex) double
Height of the day calendar view for month.
calendarYearViewHeight(DateTime firstDate, DateTime lastDate, {bool includeSubHeader = true}) double
Height of the year calendar view in a dialog.
clampDate(DateTime date, DateTime firstDate, DateTime lastDate) DateTime
clampDate.
dateOnly(DateTime date) DateTime
dateOnly.
dayPickerRowCount(DateTime month, int firstDayOfWeekIndex) int
Week rows required to display month (4–6).
daysInMonth(int year, int month) int
daysInMonth.
getDay(int year, int month, int day) DateTime
getDay.
getMonth(int year, int month) DateTime
getMonth.
isInRange(DateTime day, DateTime start, DateTime end) bool
isInRange.
isSameDay(DateTime? a, DateTime? b) bool
isSameDay.
isSelectable(DateTime date, DateTime firstDate, DateTime lastDate, {bool predicate(DateTime day)?}) bool
isSelectable.
monthDelta(DateTime startMonth, DateTime endMonth) int
monthDelta.
normalizeSelectedDay(DateTime selected, DateTime monthDate) DateTime
normalizeSelectedDay.
yearPickerGridHeight(int yearCount) double
Year grid height capped at M3EDatePickerConstants.maxDayPickerHeight.
yearPickerGridNaturalHeight(int yearCount) double
Natural height of the year grid for yearCount years.
yearPickerRowCount(int yearCount) int
Grid rows required for yearCount years.