M3EDialogTransition class

Spring-driven enter / exit for dialog routes.

Follows the route animation direction. Basic dialogs fade and scale up; full-screen dialogs slide up from the bottom edge.

Inheritance

Constructors

M3EDialogTransition({required Animation<double> animation, required M3EDialogVariant variant, required M3EDialogTheme dialogTheme, required Widget child, Key? key})
M3EDialogTransition.
const

Properties

animation → Animation<double>
Route animation; only its direction is used.
final
child → Widget
Dialog surface.
final
dialogTheme → M3EDialogTheme
Theme captured from the opening context.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variant → M3EDialogVariant
Which motion to play.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<M3EDialogTransition>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

durationFor(M3EDialogTheme theme, M3EDialogVariant variant) → Duration
Route duration that covers the slowest spring for variant.