leadingAction property
Optional third action at the leading edge (e.g. Learn more).
Use with caution: it can take people away from an unfinished task.
Implementation
final Widget? leadingAction;
Optional third action at the leading edge (e.g. Learn more).
Use with caution: it can take people away from an unfinished task.
final Widget? leadingAction;