M3EDialogStrings class abstract final

Default dialog labels.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

cancel → const String
Dismissive action label.
close → const String
Close action label.
confirm → const String
Confirming action label.
discard → const String
Discard dialog confirm action.
discardTitle → const String
Discard dialog headline.
dismiss → const String
Scrim barrier label.
expandHeadline → const String
Semantic hint for a truncated headline.
fullScreen → const String
Full-screen route barrier label.
keepEditing → const String
Discard dialog keep action.