addItems method
Adds multiple items at the end of the list.
Implementation
void addItems(List<M3EDropdownItem<T>> items) {
_items.addAll(items);
_reapplySearchFilter();
notifyListeners();
onSelectionChange?.call(selectedItems);
}
Adds multiple items at the end of the list.
void addItems(List<M3EDropdownItem<T>> items) {
_items.addAll(items);
_reapplySearchFilter();
notifyListeners();
onSelectionChange?.call(selectedItems);
}