clearSearch method
void
clearSearch()
Clears the current search query and shows all items.
This is the public API; always notifies listeners.
Implementation
void clearSearch() {
clearSearchQuery(notify: true);
}
Clears the current search query and shows all items.
This is the public API; always notifies listeners.
void clearSearch() {
clearSearchQuery(notify: true);
}