M3EExtendedFabControllerClient class abstract
Host bridge implemented by extended FAB state. Not intended for app code.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTransformOpen → bool
-
Whether a container transform overlay is showing.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
closeTransform(
) → void - Closes the container transform.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAppearRequested(
) → void - Starts the appear morph.
-
onExtendedRequested(
{required bool extended}) → void -
Animates extended state to match
extended. -
openTransform<
T extends Object?> ({WidgetBuilder? builder}) → Future< T?> - Opens the container transform.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited