physics property
How the scroll view should respond to user input.
Only used by M3ECardList.builder.
Implementation
final ScrollPhysics? physics;
How the scroll view should respond to user input.
Only used by M3ECardList.builder.
final ScrollPhysics? physics;