components/lists/utils/m3e_list_selection_fill library

Functions

m3eSelectionFill(BuildContext context, int index) Color?
Highlight fill for index when an enclosing scope has it selected.
m3eSelectionRadius(BuildContext context, int index, {double? outerRadius}) BorderRadius?
Selected equal-corner radius when list selection is active for index.