M3EMenuKeyTarget class

One keyboard-focusable row registered with an open menu.

Constructors

M3EMenuKeyTarget({required FocusNode node, required String label, required bool enabled, VoidCallback? onOpenSubmenu})
Creates a focus target for a menu row.

Properties

enabled ↔ bool
Whether arrow keys may land on this row.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
label ↔ String
Label used for typeahead.
getter/setter pair
node → FocusNode
Focus node owned by the row.
final
onOpenSubmenu ↔ VoidCallback?
Opens a cascading submenu when the row has one.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited