Builds leaf M3EMenuNode widgets for M3EMenuContent.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
customWidget(
BuildContext context, M3EMenuWidget item, {required bool autofocus, required bool closeOnSelect, required M3EMenuSelectCallback onSelect}) → Widget - customWidget.
-
entry(
M3EMenuEntry entry, {required bool autofocus, required bool closeOnSelect, required M3EMenuSelectCallback onSelect}) → Widget - entry.
-
selectable(
M3EMenuSelectable item, {required bool selected, required bool autofocus, required M3EMenuSelectCallback onSelect}) → Widget - selectable.
- submenu.
-
toggleable(
M3EMenuToggleable item, {required bool autofocus, required bool closeOnSelect, required M3EMenuSelectCallback onSelect}) → Widget - toggleable.