M3EMenuSelectable class

Single-select row with a trailing check when selected.

Inheritance
Annotations

Constructors

M3EMenuSelectable({required String label, required Object value, Widget? leading, Widget? trailing, String? trailingText, Widget? badge, String? supportingText, bool selected = false, VoidCallback? onPressed, bool enabled = true, M3EMenuItemShape shape = M3EMenuItemShape.standalone})
M3EMenuSelectable.
const

Properties

badge Widget?
badge.
final
enabled bool
enabled.
final
hashCode int
The hash code for this object.
no setterinherited
label String
label.
final
leading Widget?
leading.
final
onPressed VoidCallback?
onPressed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
selected.
final
shape M3EMenuItemShape
shape.
final
supportingText String?
supportingText.
final
trailing Widget?
trailing.
final
trailingText String?
trailingText.
final
value Object
value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited