M3EMenuSubmenu class

Cascading submenu opened from a parent row.

Inheritance
Annotations

Constructors

M3EMenuSubmenu({required String label, required List<M3EMenuNode> children, Widget? leading, Widget? badge, bool enabled = true, M3EMenuItemShape shape = M3EMenuItemShape.standalone})
M3EMenuSubmenu.
const

Properties

badge Widget?
badge.
final
children List<M3EMenuNode>
children.
final
enabled bool
enabled.
final
hashCode int
The hash code for this object.
no setterinherited
label String
label.
final
leading Widget?
leading.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape M3EMenuItemShape
shape.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited