components/navigation_bar/m3e_navigation_bar library
Classes
- Layout constants for the M3E navigation bar.
- A Material 3 Expressive navigation bar.
- A single destination in the M3E navigation bar.
-
Theme values for
M3ENavigationBar. - Resolved height/padding/icon metrics for the navigation bar.
Enums
- Horizontal placement of the destination group in M3ENavBarLayout.wide.
- Density adjustment for the navigation bar metrics.
- Controls when destination icons are shown in the navigation bar.
- The visual style of the selection indicator.
- Controls when destination labels are shown in the navigation bar.
- Destination item arrangement for the navigation bar.
- The container shape family of the navigation bar.
- The overall height variant of the navigation bar.