components/navigation_rail/m3e_navigation_rail library
Classes
- Material 3 Expressive Navigation Rail — single widget that animates between states.
- Model for a navigation destination. One class per file.
- Configuration for the rail's built-in FAB.
- Static layout constants for the navigation rail.
- Section groups a header and a list of destinations. One class per file.
-
Theme values for
M3ENavigationRail.
Enums
- Controls how labels are shown for rail destinations when the rail is expanded.
- Modality for the expanded rail.
- M3 Expressive types for the rail.
Extensions
- Convenience extension for checking the current rail type.