M3ERefreshTriggerMode enum

Controls where a pull is allowed to start a refresh.

Mirrors RefreshIndicatorTriggerMode from the reference implementation.

Inheritance
Available extensions

Values

anywhere → const M3ERefreshTriggerMode

A refresh can begin from a drag anywhere within the scrollable.

onEdge → const M3ERefreshTriggerMode

A refresh can only begin when the scrollable is already at its edge.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<M3ERefreshTriggerMode>
A constant List of the values in this enum, in order of their declaration.