components/refresh_indicator/m3e_refresh_indicator library

Classes

M3ERefreshIndicator
A Material Design 3 expressive refresh indicator.
M3ERefreshIndicatorState
class.
M3ERefreshIndicatorTheme
Theme values for M3ERefreshIndicator.

Enums

M3ERefreshStatus
The lifecycle states an M3ERefreshIndicator moves through.
M3ERefreshTriggerMode
Controls where a pull is allowed to start a refresh.

Typedefs

M3ERefreshCallback = Future<void> Function()
Signature for the callback invoked when the user triggers a refresh.