M3ESearchViewContent class

M3ESearchViewContent.

Inheritance

Constructors

M3ESearchViewContent({required M3ESearchController searchController, required M3ESearchSuggestionsBuilder suggestionsBuilder, required Animation<double> animation, required Rect viewRect, required double viewMaxWidth, required double topPadding, required bool showFullScreenView, M3ESearchViewBuilder? viewBuilder, Widget? viewLeading, Iterable<Widget>? viewTrailing, String? viewHintText, Color? viewBackgroundColor, double? viewElevation, Color? viewSurfaceTintColor, BorderSide? viewSide, OutlinedBorder? viewShape, EdgeInsetsGeometry? viewBarPadding, double? viewHeaderHeight, TextStyle? viewHeaderTextStyle, TextStyle? viewHeaderHintStyle, Color? dividerColor, BoxConstraints? viewConstraints, EdgeInsetsGeometry? viewPadding, bool? shrinkWrap, TextCapitalization? textCapitalization, ValueChanged<String>? viewOnChanged, ValueChanged<String>? viewOnSubmitted, TextInputAction? textInputAction, TextInputType? keyboardType, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, Key? key})
M3ESearchViewContent.
const

Properties

animation Animation<double>
animation.
final
dividerColor Color?
dividerColor.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType TextInputType?
keyboardType.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchController M3ESearchController
searchController.
final
showFullScreenView bool
showFullScreenView.
final
shrinkWrap bool?
shrinkWrap.
final
smartDashesType SmartDashesType?
smartDashesType.
final
smartQuotesType SmartQuotesType?
smartQuotesType.
final
suggestionsBuilder M3ESearchSuggestionsBuilder
suggestionsBuilder.
final
textCapitalization TextCapitalization?
textCapitalization.
final
textInputAction TextInputAction?
textInputAction.
final
topPadding double
topPadding.
final
viewBackgroundColor Color?
viewBackgroundColor.
final
viewBarPadding EdgeInsetsGeometry?
viewBarPadding.
final
viewBuilder M3ESearchViewBuilder?
viewBuilder.
final
viewConstraints BoxConstraints?
viewConstraints.
final
viewElevation double?
viewElevation.
final
viewHeaderHeight double?
viewHeaderHeight.
final
viewHeaderHintStyle TextStyle?
viewHeaderHintStyle.
final
viewHeaderTextStyle TextStyle?
viewHeaderTextStyle.
final
viewHintText String?
viewHintText.
final
viewLeading Widget?
viewLeading.
final
viewMaxWidth double
viewMaxWidth.
final
viewOnChanged ValueChanged<String>?
viewOnChanged.
final
viewOnSubmitted ValueChanged<String>?
viewOnSubmitted.
final
viewPadding EdgeInsetsGeometry?
viewPadding.
final
viewRect Rect
viewRect.
final
viewShape OutlinedBorder?
viewShape.
final
viewSide BorderSide?
viewSide.
final
viewSurfaceTintColor Color?
viewSurfaceTintColor.
final
viewTrailing Iterable<Widget>?
viewTrailing.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<M3ESearchViewContent>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited