components/search/controllers/m3e_search_controller library

Classes

M3ESearchAnchorHandle
Handle implemented by M3ESearchAnchor for M3ESearchController.
M3ESearchController
Controls a search view opened by M3ESearchAnchor.

Typedefs

M3ESearchAnchorChildBuilder = Widget Function(BuildContext context, M3ESearchController controller)
Signature for building the search anchor child.
M3ESearchSuggestionsBuilder = FutureOr<Iterable<Widget>> Function(BuildContext context, M3ESearchController controller)
Signature for building search suggestions from the current query.
M3ESearchViewBuilder = Widget Function(Iterable<Widget> suggestions)
Signature for laying out suggestion widgets in the search view.