M3ESearchAnchorHandle class abstract

Handle implemented by M3ESearchAnchor for M3ESearchController.

Constructors

M3ESearchAnchorHandle()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suppressFocusOpen bool
Whether focus on the anchor bar should avoid reopening the view.
no setter
viewIsOpen bool
The viewIsOpen.
no setter

Methods

closeView(String? selectedText) → void
closeView.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openView() → void
openView.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited