M3ESearchController class

Controls a search view opened by M3ESearchAnchor.

Inheritance

Constructors

M3ESearchController()

Properties

anchor M3ESearchAnchorHandle?
The currently attached search anchor handle, if any.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isAttached bool
Whether this controller is attached to a search anchor.
no setter
isOpen bool
Whether the associated search view is currently open.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection TextSelection
The currently selected range within text.
getter/setter pairinherited
suppressFocusOpen bool
Whether the anchor should ignore focus-driven openView calls.
no setter
text String
The current string the user is editing.
getter/setter pairinherited
value TextEditingValue
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
buildTextSpan({required BuildContext context, TextStyle? style, required bool withComposing}) TextSpan
Builds TextSpan from current editing value.
inherited
clear() → void
Set the value to empty.
inherited
clearComposing() → void
Set the composing region to an empty range.
inherited
closeView(String? selectedText) → void
Closes the search view, optionally setting selectedText.
detach(M3ESearchAnchorHandle anchor) → void
Detaches this controller from anchor when it is the current handle.
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
openView() → void
Opens the search view associated with this controller.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited