detach method
Detaches this controller from anchor when it is the current handle.
Implementation
void detach(M3ESearchAnchorHandle anchor) {
if (_anchor == anchor) {
_anchor = null;
}
}
Detaches this controller from anchor when it is the current handle.
void detach(M3ESearchAnchorHandle anchor) {
if (_anchor == anchor) {
_anchor = null;
}
}