isAttached property
bool
get
isAttached
Whether this controller is attached to a search anchor.
Implementation
bool get isAttached => _anchor != null;
Whether this controller is attached to a search anchor.
bool get isAttached => _anchor != null;