M3ESegmentedButtonDensity enum
Spec density levels 0, −1, −2, −3.
Density shrinks container height (−4dp per level).
- Inheritance
- Available extensions
Values
- regular → const M3ESegmentedButtonDensity
-
Level 0 — full token container height (40dp).
- comfortable → const M3ESegmentedButtonDensity
-
Level −1 (36dp).
- compact → const M3ESegmentedButtonDensity
-
Level −2 (32dp).
- dense → const M3ESegmentedButtonDensity
-
Level −3 (28dp).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- heightAdjustment → double
-
Available on M3ESegmentedButtonDensity, provided by the M3ESegmentedButtonDensityX extension
Height delta in dp (−4.0 per density level).no setter - index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- level → int
-
Available on M3ESegmentedButtonDensity, provided by the M3ESegmentedButtonDensityX extension
Spec density level (0, −1, −2, −3).no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
M3ESegmentedButtonDensity> - A constant List of the values in this enum, in order of their declaration.