M3ESegment<T> class

A single option within an M3ESegmentedButton.

Annotations

Constructors

M3ESegment({required T value, String? label, Widget? icon})
M3ESegment.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon Widget?
The optional leading icon.
final
label String?
The optional text label.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
The value reported when this segment is selected.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited