M3ESegmentedButtonTheme class

Theme values for M3ESegmentedButton.

Inheritance
Annotations

Constructors

M3ESegmentedButtonTheme({double height = 40, double iconSize = 18, double segmentHorizontalPadding = 12, double iconLabelGap = 8, double borderWidth = 1})
M3ESegmentedButtonTheme.
const

Properties

borderRadius BorderRadius
The borderRadius.
no setter
borderWidth double
borderWidth.
final
hashCode int
The hash code for this object.
no setterinherited
height double
height.
final
iconLabelGap double
iconLabelGap.
final
iconSize double
iconSize.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segmentHorizontalPadding double
segmentHorizontalPadding.
final

Methods

backgroundColor(M3EColorScheme scheme, {required bool selected}) Color?
backgroundColor.
copyWith({double? height, double? iconSize, double? segmentHorizontalPadding, double? iconLabelGap, double? borderWidth}) M3ESegmentedButtonTheme
Returns a copy with non-null fields replaced.
override
foregroundColor(M3EColorScheme scheme, {required bool selected}) Color
foregroundColor.
lerp(M3ESegmentedButtonTheme? other, double t) M3ESegmentedButtonTheme
Linearly interpolates between this theme and other.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaults → const M3ESegmentedButtonTheme
defaults.