M3ESelectionTheme class
Theme values for selection list and selection app bar.
- Inheritance
-
- Object
- M3EThemeExtension<
M3ESelectionTheme> - M3ESelectionTheme
- Annotations
Constructors
- M3ESelectionTheme({double outerRadius = M3EListCardListTheme.defaultOuterRadius, double innerRadius = M3EListCardListTheme.defaultInnerRadius, double gap = M3EListCardListTheme.defaultGap, EdgeInsetsGeometry itemPadding = M3EListCardListTheme.defaultItemPadding, M3ECardVariant variant = M3ECardVariant.filled, BorderSide? border, Duration leadingFlipDuration = const Duration(milliseconds: 220), double selectAllHeight = 48, double contextualToolbarHeight = 72, Color? highlightColor})
-
Creates a selection theme.
const
Properties
- border → BorderSide?
-
Optional outline.
final
- contextualToolbarHeight → double
-
Height of the contextual selection toolbar (excluding safe area).
final
- gap → double
-
Gap between cards.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightColor → Color?
-
Optional selected-item fill. Defaults to the secondary container.
final
- innerRadius → double
-
Inner card radius for unselected stacked cards.
final
- itemPadding → EdgeInsetsGeometry
-
Padding inside each card.
final
- leadingFlipDuration → Duration
-
Duration for leading horizontal flip.
final
- outerRadius → double
-
Outer card radius (also used for selected equal corners).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectAllHeight → double
-
Height of the select-all row under the contextual bar.
final
- variant → M3ECardVariant
-
Card variant.
final
Methods
-
contextualBackground(
M3EColorScheme scheme) → Color - Contextual selection app bar container.
-
contextualForeground(
M3EColorScheme scheme) → Color - Content on the contextual selection app bar.
-
copyWith(
{double? outerRadius, double? innerRadius, double? gap, EdgeInsetsGeometry? itemPadding, M3ECardVariant? variant, BorderSide? border, Duration? leadingFlipDuration, double? selectAllHeight, double? contextualToolbarHeight, Color? highlightColor}) → M3ESelectionTheme -
Returns a copy with non-null fields replaced.
override
-
lerp(
M3ESelectionTheme? other, double t) → M3ESelectionTheme -
Linearly interpolates between this theme and
other.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
selectedColor(
M3EColorScheme scheme) → Color - Selected card fill.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const M3ESelectionTheme
- defaults.