M3ESideSheetSurface class

Side sheet container: color, tint, elevation and corner shape.

modal blends the standard (0) and modal (1) looks while the sheet morphs between them.

Inheritance

Constructors

M3ESideSheetSurface({required M3ESideSheetTheme theme, required double modal, required BorderRadius borderRadius, required Widget child, Key? key})
M3ESideSheetSurface.
const

Properties

borderRadius → BorderRadius
Current corner shape.
final
child → Widget
Sheet content.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
0 for standard, 1 for modal.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme → M3ESideSheetTheme
Resolved sheet theme.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

tintOpacity(double elevation) → double
Tint opacity for M3 elevation levels.