M3ESideSheetController class

Opens and closes a side sheet without user input.

Pass it to M3ESideSheetLayout or M3ESideSheet.show.

Inheritance

Constructors

M3ESideSheetController()
M3ESideSheetController.

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isAttached → bool
Whether a sheet is attached.
no setter
isOpen → bool
Whether the attached sheet is open; false when detached.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
attach(M3ESideSheetControllerClient client) → void
Binds client. Called by the sheet host.
close([Object? result]) → void
Closes the attached sheet; a modal route pops with result.
detach(M3ESideSheetControllerClient client) → void
Unbinds client. Called by the sheet host.
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
open() → void
Opens the attached sheet.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toggle() → void
Opens a closed sheet and closes an open one.
toString() → String
A string representation of this object.
inherited
updateOpen({required bool isOpen}) → void
Reports whether the sheet is open. Called by the sheet host.

Operators

operator ==(Object other) → bool
The equality operator.
inherited