M3ESideSheetTheme class

Theme values for M3ESideSheet.

Inheritance
Annotations

Constructors

M3ESideSheetTheme({double width = 320, double cornerRadius = 28, double scrimOpacity = 0.32, EdgeInsets headerPadding = const EdgeInsets.fromLTRB(24, 16, 8, 16), EdgeInsets closeButtonPadding = const EdgeInsets.all(12), double iconSize = 24, EdgeInsets actionsPadding = const EdgeInsets.all(16)})
M3ESideSheetTheme.
const

Properties

actionsPadding EdgeInsets
actionsPadding.
final
closeButtonPadding EdgeInsets
closeButtonPadding.
final
cornerRadius double
cornerRadius.
final
hashCode int
The hash code for this object.
no setterinherited
headerPadding EdgeInsets
headerPadding.
final
iconSize double
iconSize.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrimOpacity double
scrimOpacity.
final
width double
width.
final

Methods

containerColor(M3EColorScheme scheme) Color
containerColor.
copyWith({double? width, double? cornerRadius, double? scrimOpacity, EdgeInsets? headerPadding, EdgeInsets? closeButtonPadding, double? iconSize, EdgeInsets? actionsPadding}) M3ESideSheetTheme
Returns a copy with non-null fields replaced.
override
dividerColor(M3EColorScheme scheme) Color
dividerColor.
lerp(M3ESideSheetTheme? other, double t) M3ESideSheetTheme
Linearly interpolates between this theme and other.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scrimColor(M3EColorScheme scheme) Color
scrimColor.
titleStyle(M3ETypeScale type, M3EColorScheme scheme) TextStyle
titleStyle.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaults → const M3ESideSheetTheme
defaults.