M3ESnackbarController class

Programmatic show / dismiss for snackbars (one at a time).

New present calls replace any currently visible snackbar. Prefer M3ESnackbar.show which routes through this controller (or a custom one).

Inheritance

Constructors

M3ESnackbarController()
Creates a snackbar controller.

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isShowing → bool
Whether a snackbar overlay is currently mounted.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
attachHost(M3ESnackbarHostState host) → void
Binds the active host (called by M3ESnackbarHost).
detachHost(M3ESnackbarHostState host) → void
Releases the host without disposing this controller.
dismiss({bool immediate = false}) → void
Dismisses the current snackbar.
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyClosed(OverlayEntry entry) → void
Called by the host after exit animation completes.
notifyListeners() → void
Call all the registered listeners.
inherited
present(BuildContext context, {required Widget child, Duration? duration}) → void
Inserts child in a snackbar host, replacing any current bar.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited