M3ESplitButtonItem<T> class

A single selectable entry in an M3ESplitButton menu.

Constructors

M3ESplitButtonItem({required T value, required Object child, bool enabled = true})
M3ESplitButtonItem.
const

Properties

child Object
child.
final
enabled bool
enabled.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited