M3ESwitch class

A Material 3 Expressive switch.

Toggles a single setting on or off. The handle slides and grows with the existing thumb springs. A 40dp state layer and focus ring follow the handle inside a 48dp target.

Inheritance

Constructors

M3ESwitch({required bool value, required ValueChanged<bool>? onChanged, Widget? selectedIcon, Widget? unselectedIcon, double? stateLayerSize, FocusNode? focusNode, bool autofocus = false, String? semanticLabel, Key? key})
M3ESwitch.
const

Properties

autofocus → bool
autofocus.
final
focusNode → FocusNode?
focusNode.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged → ValueChanged<bool>?
onChanged.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedIcon → Widget?
selectedIcon.
final
semanticLabel → String?
semanticLabel.
final
stateLayerSize → double?
Diameter of the handle-centered state layer.
final
unselectedIcon → Widget?
unselectedIcon.
final
value → bool
value.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<M3ESwitch>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited