M3ESwitchTheme class
Theme values for M3ESwitch.
- Inheritance
-
- Object
- M3EThemeExtension<
M3ESwitchTheme> - M3ESwitchTheme
- Annotations
Constructors
- M3ESwitchTheme({double trackWidth = 52, double trackHeight = 32, double trackPadding = 4, double thumbSizePressed = 28, double thumbSizeSelected = 24, double thumbSizeUnselected = 16, double stateLayerSize = 48, double iconSize = 16, double borderWidth = 2, double disabledTrackOpacity = 0.12, double disabledThumbOpacity = 0.38, double disabledOutlineOpacity = 0.12})
-
M3ESwitchTheme.
const
Properties
- borderWidth → double
-
borderWidth.
final
- disabledOutlineOpacity → double
-
disabledOutlineOpacity.
final
- disabledThumbOpacity → double
-
disabledThumbOpacity.
final
- disabledTrackOpacity → double
-
disabledTrackOpacity.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconSize → double
-
iconSize.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stateLayerSize → double
-
Diameter of the thumb-centered hover/focus/press state layer.
final
- thumbSizePressed → double
-
thumbSizePressed.
final
- thumbSizeSelected → double
-
thumbSizeSelected.
final
- thumbSizeUnselected → double
-
thumbSizeUnselected.
final
- trackHeight → double
-
trackHeight.
final
- trackPadding → double
-
trackPadding.
final
- trackWidth → double
-
trackWidth.
final
Methods
-
copyWith(
{double? trackWidth, double? trackHeight, double? trackPadding, double? thumbSizePressed, double? thumbSizeSelected, double? thumbSizeUnselected, double? stateLayerSize, double? iconSize, double? borderWidth, double? disabledTrackOpacity, double? disabledThumbOpacity, double? disabledOutlineOpacity}) → M3ESwitchTheme -
Returns a copy with non-null fields replaced.
override
-
iconColor(
M3EColorScheme scheme, {required bool value}) → Color - iconColor.
-
lerp(
M3ESwitchTheme? other, double t) → M3ESwitchTheme -
Linearly interpolates between this theme and
other.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
outlineColor(
M3EColorScheme scheme, {required bool enabled}) → Color - outlineColor.
-
stateLayerColor(
M3EColorScheme scheme, {required bool value}) → Color - stateLayerColor.
-
thumbColor(
M3EColorScheme scheme, {required bool enabled, required bool value}) → Color - thumbColor.
-
thumbSize(
{required bool pressed, required bool grown}) → double - thumbSize.
-
toString(
) → String -
A string representation of this object.
inherited
-
trackColor(
M3EColorScheme scheme, {required bool enabled, required bool value}) → Color - trackColor.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const M3ESwitchTheme
- defaults.