detach method
Drops the bar when select is still the bound callback.
Implementation
void detach(ValueChanged<int> select) {
if (!identical(_select, select)) {
return;
}
_select = null;
}
Drops the bar when select is still the bound callback.
void detach(ValueChanged<int> select) {
if (!identical(_select, select)) {
return;
}
_select = null;
}