M3ETabsAlignment enum

How fixed tabs share the bar width.

Inheritance
Available extensions

Values

fill → const M3ETabsAlignment

Equal sections across the full container.

center → const M3ETabsAlignment

Each tab is as wide as the widest tab, and the group is centered.

leading → const M3ETabsAlignment

Each tab is as wide as the widest tab, and the group starts at the edge.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<M3ETabsAlignment>
A constant List of the values in this enum, in order of their declaration.