M3ETextFieldVariant enum

The two text field container styles defined by Material 3.

Inheritance
Available extensions

Values

filled → const M3ETextFieldVariant

Filled container with a bottom activation indicator.

outlined → const M3ETextFieldVariant

Transparent container with a full outline.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<M3ETextFieldVariant>
A constant List of the values in this enum, in order of their declaration.