components/text_fields/m3e_text_fields library
Classes
- M3ETextField
- A Material 3 Expressive text field.
- M3ETextFieldColors
-
Resolved colors and stroke width for one
M3ETextFieldstate. - M3ETextFieldColorTheme
-
Color tokens for
M3ETextField. - M3ETextFieldStates
-
Interaction snapshot used to resolve
M3ETextFieldtokens. - M3ETextFieldTheme
-
Theme values for
M3ETextField.
Enums
- M3ETextFieldSlotAlignment
-
Vertical position of
M3ETextFieldicons or prefix/suffix text when the field is taller than one line (multi-line or text area). - M3ETextFieldVariant
- The two text field container styles defined by Material 3.
Functions
-
m3eDefaultTextFieldContextMenuBuilder(
BuildContext context, EditableTextState editableTextState) → Widget - Default context menu: the platform adaptive selection toolbar.
-
m3eTextFieldCounterLabel(
int count, int maxLength) → String - Default counter label: "Character count, N of M characters entered".
Typedefs
- M3ETextFieldCounterLabelBuilder = String Function(int count, int maxLength)
- Builds the character counter label for assistive tech.