components/toolbars/components/m3e_toolbar_fab_layout library

Classes

M3EToolbarFabLayoutParentData
Parent data for FAB + pill morph layouts.
M3EToolbarHorizontalFabLayout
Horizontal FAB + toolbar morph (pill grows opposite the FAB).
M3EToolbarVerticalFabLayout
Vertical FAB + toolbar morph (pill grows opposite the FAB).
RenderM3EToolbarHorizontalFabLayout
Lays out a horizontal toolbar pill alongside a morphing FAB.
RenderM3EToolbarVerticalFabLayout
Lays out a vertical toolbar pill alongside a morphing FAB.