labelGap constant
double
const labelGap
Gap between the icon and label inside an expanded action.
Implementation
static const double labelGap = 6;
Gap between the icon and label inside an expanded action.
static const double labelGap = 6;