pillActiveSpring property
Reserved for parent M3EToolbar.pillActiveSpring; labeled width always follows the morph spring so padding and animation stay correct.
Implementation
final bool pillActiveSpring;
Reserved for parent M3EToolbar.pillActiveSpring; labeled width always follows the morph spring so padding and animation stay correct.
final bool pillActiveSpring;