M3EToolbarContentAlignment enum

How docked actions use leftover width at the medium window size and up.

Below 600dp the bar always uses even.

Inheritance
Available extensions

Values

even → const M3EToolbarContentAlignment

Equal gaps, preferring 32 and shrinking toward 4 when the bar is tight.

centered → const M3EToolbarContentAlignment

Actions clustered in the center with the theme centered gap.

edges → const M3EToolbarContentAlignment

Leading and trailing groups with a flexible middle.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<M3EToolbarContentAlignment>
A constant List of the values in this enum, in order of their declaration.