M3EToolbarAction class

An icon action hosted by M3EToolbar.

Inheritance

Constructors

M3EToolbarAction({required IconData icon, required VoidCallback onPressed, String? tooltip, String? semanticLabel, bool enabled = true, String? label, bool isDestructive = false, bool active = false, bool isExpandTrigger = false})
M3EToolbarAction.
const

Properties

active bool
When true, uses filled / trigger-like coloring.
final
enabled bool
enabled.
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
icon.
final
isDestructive bool
When true, the overflow menu entry uses the error color.
final
isExpandTrigger bool
Marks this action as the floating-toolbar expand/collapse trigger.
final
label String?
Label shown inside the action button when active is true.
final
onPressed VoidCallback
onPressed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
semanticLabel.
final
tooltip String?
tooltip.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited