active property
When true, uses filled / trigger-like coloring.
When M3EToolbar.onActiveIndexChanged is set, the toolbar owns selection and overwrites this. Otherwise the flag is respected as provided.
Implementation
final bool active;
When true, uses filled / trigger-like coloring.
When M3EToolbar.onActiveIndexChanged is set, the toolbar owns selection and overwrites this. Otherwise the flag is respected as provided.
final bool active;