M3EToolbarWidget class

Custom content hosted inline in M3EToolbar.actions.

Always stays inline (never moves to the overflow menu). Laid out within the bar's available cross-axis extent after content padding.

Inheritance

Constructors

M3EToolbarWidget({required Widget child, String? semanticLabel})
M3EToolbarWidget.
const

Properties

child → Widget
child.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel → String?
semanticLabel.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited