M3EToolbarMetrics class

Resolved layout metrics for floating / docked toolbars.

Annotations

Constructors

M3EToolbarMetrics({required double crossAxisSize, required EdgeInsetsGeometry contentPadding, required double gap, required double iconSize, required double elevation, required double elevationWithFab})
M3EToolbarMetrics.
const

Properties

contentPadding EdgeInsetsGeometry
contentPadding.
final
crossAxisSize double
crossAxisSize.
final
elevation double
elevation.
final
elevationWithFab double
elevationWithFab.
final
gap double
gap.
final
hashCode int
The hash code for this object.
no setterinherited
iconSize double
iconSize.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited