M3EToolbarTheme class

Theme values for M3EToolbar.

Inheritance
Annotations

Constructors

M3EToolbarTheme({double containerSize = M3EToolbarTokens.containerSize, double floatingPadding = M3EToolbarTokens.floatingContentPadding, double dockedHorizontalPadding = M3EToolbarTokens.dockedHorizontalPadding, double iconSize = 24, double elevation = M3EToolbarTokens.elevationNone, double elevationWithFab = M3EToolbarTokens.elevationWithFabExpanded, double toolbarToFabGap = M3EToolbarTokens.toolbarToFabGap, double screenOffset = M3EToolbarTokens.screenOffset, double heightSmall = 40, double heightMedium = 48, double heightLarge = 56, double compactHeightReduction = 4, double elevationSurface = 0, double elevationProminent = 2})
M3EToolbarTheme.
const

Properties

compactHeightReduction double
compactHeightReduction.
final
containerSize double
containerSize.
final
dockedHorizontalPadding double
dockedHorizontalPadding.
final
elevation double
elevation.
final
elevationProminent double
elevationProminent.
final
elevationSurface double
elevationSurface.
final
elevationWithFab double
elevationWithFab.
final
floatingPadding double
floatingPadding.
final
hashCode int
The hash code for this object.
no setterinherited
heightLarge double
heightLarge.
final
heightMedium double
heightMedium.
final
heightSmall double
heightSmall.
final
iconSize double
iconSize.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenOffset double
screenOffset.
final
toolbarToFabGap double
toolbarToFabGap.
final

Methods

colors(M3EColorScheme scheme, M3EToolbarColorStyle style) M3EToolbarColors
colors.
colorStyleFromVariant(M3EToolbarVariant variant) M3EToolbarColorStyle
Maps legacy M3EToolbarVariant onto M3EToolbarColorStyle.
containerColor(M3EColorScheme scheme, M3EToolbarVariant variant) Color
containerColor.
copyWith({double? containerSize, double? floatingPadding, double? dockedHorizontalPadding, double? iconSize, double? elevation, double? elevationWithFab, double? toolbarToFabGap, double? screenOffset, double? heightSmall, double? heightMedium, double? heightLarge, double? compactHeightReduction, double? elevationSurface, double? elevationProminent}) M3EToolbarTheme
Returns a copy with non-null fields replaced.
override
dockedShape() ShapeBorder
dockedShape.
floatingShape() ShapeBorder
floatingShape.
foregroundColor(M3EColorScheme scheme, M3EToolbarVariant variant) Color
foregroundColor.
iconButtonSize(M3EToolbarSize size) M3EIconButtonSize
iconButtonSize.
lerp(M3EToolbarTheme? other, double t) M3EToolbarTheme
Linearly interpolates between this theme and other.
override
metrics(M3EToolbarDensity density, M3ESpacing spacing) M3EToolbarMetrics
Legacy metrics API used by older call sites.
metricsFor(M3EToolbarPlacement placement) M3EToolbarMetrics
metricsFor.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scopedTheme(M3EThemeData base, Color foreground) M3EThemeData
scopedTheme.
shape(M3EToolbarShapeFamily family) ShapeBorder
shape.
subtitleStyle(M3ETypeScale typeScale) TextStyle
subtitleStyle.
titleStyle(M3ETypeScale typeScale) TextStyle
titleStyle.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaults → const M3EToolbarTheme
defaults.