M3ETooltipPlacement enum

Preferred placement of a tooltip relative to its child.

Inheritance
Available extensions

Values

above → const M3ETooltipPlacement

Centered above the target (plain default).

below → const M3ETooltipPlacement

Centered below the target (e.g. app bars).

bottomStart → const M3ETooltipPlacement

Below toward the leading edge.

bottomEnd → const M3ETooltipPlacement

Below toward the trailing edge (rich default).

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<M3ETooltipPlacement>
A constant List of the values in this enum, in order of their declaration.