showFocusFill property
bool
get
showFocusFill
Focus fill when rings are not the keyboard chrome.
Implementation
bool get showFocusFill =>
focused && !M3EFocusInteraction.instance.ringsAllowed;
Focus fill when rings are not the keyboard chrome.
bool get showFocusFill =>
focused && !M3EFocusInteraction.instance.ringsAllowed;