M3EShapeKind enum

Catalog of Material 3 Expressive morph polygons for clipping and fill.

Inheritance
Available extensions

Values

circle → const M3EShapeKind

Circle.

square → const M3EShapeKind

Rounded square.

slanted → const M3EShapeKind

Slanted square.

arch → const M3EShapeKind

Arch.

semiCircle → const M3EShapeKind

Semi-circle.

oval → const M3EShapeKind

Oval.

pill → const M3EShapeKind

Pill.

triangle → const M3EShapeKind

Triangle.

arrow → const M3EShapeKind

Arrow.

fan → const M3EShapeKind

Fan.

diamond → const M3EShapeKind

Diamond.

clamShell → const M3EShapeKind

Clam shell.

pentagon → const M3EShapeKind

Pentagon.

gem → const M3EShapeKind

Gem.

sunny → const M3EShapeKind

Sunny.

verySunny → const M3EShapeKind

Very sunny.

cookie4Sided → const M3EShapeKind

Four-sided cookie.

cookie6Sided → const M3EShapeKind

Six-sided cookie.

cookie7Sided → const M3EShapeKind

Seven-sided cookie.

cookie9Sided → const M3EShapeKind

Nine-sided cookie.

cookie12Sided → const M3EShapeKind

Twelve-sided cookie.

clover4Leaf → const M3EShapeKind

Four-leaf clover.

clover8Leaf → const M3EShapeKind

Eight-leaf clover.

burst → const M3EShapeKind

Burst.

softBurst → const M3EShapeKind

Soft burst.

boom → const M3EShapeKind

Boom.

softBoom → const M3EShapeKind

Soft boom.

flower → const M3EShapeKind

Flower.

puffy → const M3EShapeKind

Puffy.

puffyDiamond → const M3EShapeKind

Puffy diamond.

ghostish → const M3EShapeKind

Ghostish.

pixelCircle → const M3EShapeKind

Pixel circle.

pixelTriangle → const M3EShapeKind

Pixel triangle.

bun → const M3EShapeKind

Bun.

heart → const M3EShapeKind

Heart.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
polygon RoundedPolygon
Morph polygon for this kind.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

all List<M3EShapeKind>
Every catalog entry, in declaration order.
no setter

Constants

values → const List<M3EShapeKind>
A constant List of the values in this enum, in order of their declaration.