M3EShapeSet class

A five-step BorderRadius scale for a single shape family.

Mirrors the M3EShapeSet from the m3e_design package.

Annotations

Constructors

M3EShapeSet({required BorderRadius xs, required BorderRadius sm, required BorderRadius md, required BorderRadius lg, required BorderRadius xl})
Creates a five-step shape set.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lg BorderRadius
Large corner radius in this family.
final
md BorderRadius
Medium corner radius in this family.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm BorderRadius
Small corner radius in this family.
final
xl BorderRadius
Extra-large corner radius in this family.
final
xs BorderRadius
Extra-small corner radius in this family.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited