Material 3 Expressive shape (corner radius) tokens.
The expressive shape scale extends the baseline scale with the
largeIncreased, extraLargeIncreased and extraExtraLarge steps used by
the new large components (FAB menu, toolbars, expressive buttons).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
resolve(
double token) → BorderRadius - Resolves a corner radius token to a BorderRadius.
Constants
- extraExtraLarge → const double
- 48dp corner radius.
- extraLarge → const double
- 28dp corner radius.
- extraLargeIncreased → const double
- 32dp corner radius (expressive XL+).
- extraSmall → const double
- 4dp corner radius.
- full → const double
- Sentinel radius that resolves to a fully rounded (stadium) shape.
- large → const double
- 16dp corner radius.
- largeIncreased → const double
- 20dp corner radius (expressive large+).
- medium → const double
- 12dp corner radius.
- none → const double
- 0dp — sharp corners.
- radiusExtraExtraLarge → const BorderRadius
- BorderRadius for extraExtraLarge.
- radiusExtraLarge → const BorderRadius
- BorderRadius for extraLarge.
- radiusExtraLargeIncreased → const BorderRadius
- BorderRadius for extraLargeIncreased.
- radiusExtraSmall → const BorderRadius
- BorderRadius for extraSmall.
- radiusLarge → const BorderRadius
- BorderRadius for large.
- radiusLargeIncreased → const BorderRadius
- BorderRadius for largeIncreased.
- radiusMedium → const BorderRadius
- BorderRadius for medium.
- radiusNone → const BorderRadius
- BorderRadius for none.
- radiusSmall → const BorderRadius
- BorderRadius for small.
- roundSet → const M3EShapeSet
-
The expressive round shape set (mirrors
m3e_design's round family). - small → const double
- 8dp corner radius.
- squareSet → const M3EShapeSet
-
The expressive square shape set (mirrors
m3e_design's square family). - stadium → const StadiumBorder
- Fully rounded stadium shape border.