M3EStateOpacity class abstract final

Material 3 state layer opacity tokens.

State layers are translucent overlays of a role color painted on top of a component to communicate hover, focus, pressed and dragged states.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

disabledContainer → const double
Opacity applied to the container of a disabled component.
disabledContent → const double
Opacity applied to content (icon/label) of a disabled component.
dragged → const double
Dragged state-layer opacity (16%).
focus → const double
Focus state-layer opacity (10%).
hover → const double
Hover state-layer opacity (8%).
pressed → const double
Pressed state-layer opacity (10%).