state property
The active interaction state driving fallback overlays when no ink scope is present.
Implementation
final M3EInteractionState state;
The active interaction state driving fallback overlays when no ink scope is present.
final M3EInteractionState state;