M3EThemeData class

Immutable bundle of expressive design tokens and per-component themes.

Annotations

Constructors

M3EThemeData({M3EColorScheme? colorScheme, M3ETypeScale? typeScale, IconThemeData iconTheme = const IconThemeData(size: 24), M3ESpacing spacing = const M3ESpacing.regular(), double visualDensity = 0, TargetPlatform? platform, bool useMaterial3 = true, Color? splashColor, Color? highlightColor, M3EAppBarTheme appBarTheme = M3EAppBarTheme.defaults, M3EBadgeTheme badgeTheme = M3EBadgeTheme.defaults, M3EBottomSheetTheme bottomSheetTheme = M3EBottomSheetTheme.defaults, M3EButtonTheme buttonTheme = M3EButtonTheme.defaults, M3ECardTheme cardTheme = M3ECardTheme.defaults, M3ECarouselTheme carouselTheme = M3ECarouselTheme.defaults, M3ECheckboxTheme checkboxTheme = M3ECheckboxTheme.defaults, M3EChipTheme chipTheme = M3EChipTheme.defaults, M3EDatePickerTheme datePickerTheme = M3EDatePickerTheme.defaults, M3EDialogTheme dialogTheme = M3EDialogTheme.defaults, M3EDividerTheme dividerTheme = M3EDividerTheme.defaults, M3EDropdownMenuTheme dropdownMenuTheme = M3EDropdownMenuTheme.defaults, M3EFabTheme fabTheme = M3EFabTheme.defaults, M3EFabMenuTheme fabMenuTheme = M3EFabMenuTheme.defaults, M3EIconButtonTheme iconButtonTheme = M3EIconButtonTheme.defaults, M3EListTheme listTheme = M3EListTheme.defaults, M3ELoadingIndicatorTheme loadingIndicatorTheme = M3ELoadingIndicatorTheme.defaults, M3EMenuTheme menuTheme = M3EMenuTheme.defaults, M3ENavigationBarTheme navigationBarTheme = M3ENavigationBarTheme.defaults, M3ENavigationDrawerTheme navigationDrawerTheme = M3ENavigationDrawerTheme.defaults, M3ENavigationRailTheme navigationRailTheme = M3ENavigationRailTheme.defaults, M3EProgressIndicatorTheme progressIndicatorTheme = M3EProgressIndicatorTheme.defaults, M3ERadioTheme radioTheme = M3ERadioTheme.defaults, M3ERefreshIndicatorTheme refreshIndicatorTheme = M3ERefreshIndicatorTheme.defaults, M3ESearchBarTheme searchBarTheme = M3ESearchBarTheme.defaults, M3ESearchViewTheme searchViewTheme = M3ESearchViewTheme.defaults, M3ESegmentedButtonTheme segmentedButtonTheme = M3ESegmentedButtonTheme.defaults, M3ESideSheetTheme sideSheetTheme = M3ESideSheetTheme.defaults, M3ESliderTheme sliderTheme = M3ESliderTheme.defaults, M3ESnackbarTheme snackBarTheme = M3ESnackbarTheme.defaults, M3ESplitButtonTheme splitButtonTheme = M3ESplitButtonTheme.defaults, M3ESwitchTheme switchTheme = M3ESwitchTheme.defaults, M3ETabTheme tabTheme = M3ETabTheme.defaults, M3ETextFieldTheme textFieldTheme = M3ETextFieldTheme.defaults, M3ETimePickerTheme timePickerTheme = M3ETimePickerTheme.defaults, M3EToggleButtonTheme toggleButtonTheme = M3EToggleButtonTheme.defaults, M3EToggleButtonGroupTheme toggleButtonGroupTheme = M3EToggleButtonGroupTheme.defaults, M3EToolbarTheme toolbarTheme = M3EToolbarTheme.defaults, M3ETooltipTheme tooltipTheme = M3ETooltipTheme.defaults})
Creates an expressive theme from tokens and component themes.
M3EThemeData.dark({Color? seedColor})
Dark theme, optionally seeded from seedColor.
factory
M3EThemeData.fromMaterial(ThemeData theme)
Adapts a Material ThemeData into an M3EThemeData.
factory
M3EThemeData.light({Color? seedColor})
Light theme, optionally seeded from seedColor.
factory

Properties

appBarTheme M3EAppBarTheme
App bar component theme.
final
badgeTheme M3EBadgeTheme
Badge component theme.
final
bottomSheetTheme M3EBottomSheetTheme
Bottom sheet component theme.
final
brightness Brightness
Brightness derived from colorScheme.
final
buttonTheme M3EButtonTheme
Button component theme.
final
cardTheme M3ECardTheme
Card component theme.
final
carouselTheme M3ECarouselTheme
Carousel component theme.
final
checkboxTheme M3ECheckboxTheme
Checkbox component theme.
final
chipTheme M3EChipTheme
Chip component theme.
final
colorScheme M3EColorScheme
Color roles for this theme.
final
datePickerTheme M3EDatePickerTheme
Date picker component theme.
final
dialogTheme M3EDialogTheme
Dialog component theme.
final
dividerTheme M3EDividerTheme
Divider component theme.
final
Dropdown menu component theme.
final
fabMenuTheme M3EFabMenuTheme
FAB menu component theme.
final
fabTheme M3EFabTheme
FAB component theme.
final
hashCode int
The hash code for this object.
no setterinherited
highlightColor Color?
Optional highlight color override for ink.
final
iconButtonTheme M3EIconButtonTheme
Icon button component theme.
final
iconTheme IconThemeData
Default icon size/opacity/etc. When color is null, icons use M3EColorScheme.onSurface (including after dynamic color updates).
final
listTheme M3EListTheme
List component theme.
final
loadingIndicatorTheme M3ELoadingIndicatorTheme
Loading indicator component theme.
final
Menu component theme.
final
Navigation bar component theme.
final
Navigation drawer component theme.
final
Navigation rail component theme.
final
platform TargetPlatform?
Target platform overrides, if any.
final
progressIndicatorTheme M3EProgressIndicatorTheme
Progress indicator component theme.
final
radioTheme M3ERadioTheme
Radio button component theme.
final
refreshIndicatorTheme M3ERefreshIndicatorTheme
Refresh indicator component theme.
final
resolvedIconTheme IconThemeData
iconTheme with M3EColorScheme.onSurface when no explicit color is set.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchBarTheme M3ESearchBarTheme
Search bar component theme.
final
searchViewTheme M3ESearchViewTheme
Search view component theme.
final
segmentedButtonTheme M3ESegmentedButtonTheme
Segmented button component theme.
final
sideSheetTheme M3ESideSheetTheme
Side sheet component theme.
final
sliderTheme M3ESliderTheme
Slider component theme.
final
snackBarTheme M3ESnackbarTheme
Snackbar component theme.
final
spacing M3ESpacing
Spacing scale for this theme.
final
splashColor Color?
Optional splash color override for ink.
final
splitButtonTheme M3ESplitButtonTheme
Split button component theme.
final
switchTheme M3ESwitchTheme
Switch component theme.
final
tabTheme M3ETabTheme
Tab component theme.
final
textFieldTheme M3ETextFieldTheme
Text field component theme.
final
textTheme TextTheme
typeScale as a Material TextTheme, colored with M3EColorScheme.onSurface so it tracks the active scheme.
no setter
timePickerTheme M3ETimePickerTheme
Time picker component theme.
final
toggleButtonGroupTheme M3EToggleButtonGroupTheme
Toggle button group component theme.
final
toggleButtonTheme M3EToggleButtonTheme
Toggle button component theme.
final
toolbarTheme M3EToolbarTheme
Toolbar component theme.
final
tooltipTheme M3ETooltipTheme
Tooltip component theme.
final
typeScale M3ETypeScale
Type scale for this theme.
final
useMaterial3 bool
Whether Material 3 behavior is enabled in toThemeData.
final
visualDensity double
Visual density offset applied to Material VisualDensity.
final

Methods

copyWith({M3EColorScheme? colorScheme, M3ETypeScale? typeScale, IconThemeData? iconTheme, M3ESpacing? spacing, double? visualDensity, TargetPlatform? platform, bool? useMaterial3, Color? splashColor, Color? highlightColor, M3EAppBarTheme? appBarTheme, M3EBadgeTheme? badgeTheme, M3EBottomSheetTheme? bottomSheetTheme, M3EButtonTheme? buttonTheme, M3ECardTheme? cardTheme, M3ECarouselTheme? carouselTheme, M3ECheckboxTheme? checkboxTheme, M3EChipTheme? chipTheme, M3EDatePickerTheme? datePickerTheme, M3EDialogTheme? dialogTheme, M3EDividerTheme? dividerTheme, M3EDropdownMenuTheme? dropdownMenuTheme, M3EFabTheme? fabTheme, M3EFabMenuTheme? fabMenuTheme, M3EIconButtonTheme? iconButtonTheme, M3EListTheme? listTheme, M3ELoadingIndicatorTheme? loadingIndicatorTheme, M3EMenuTheme? menuTheme, M3ENavigationBarTheme? navigationBarTheme, M3ENavigationDrawerTheme? navigationDrawerTheme, M3ENavigationRailTheme? navigationRailTheme, M3EProgressIndicatorTheme? progressIndicatorTheme, M3ERadioTheme? radioTheme, M3ERefreshIndicatorTheme? refreshIndicatorTheme, M3ESearchBarTheme? searchBarTheme, M3ESearchViewTheme? searchViewTheme, M3ESegmentedButtonTheme? segmentedButtonTheme, M3ESideSheetTheme? sideSheetTheme, M3ESliderTheme? sliderTheme, M3ESnackbarTheme? snackBarTheme, M3ESplitButtonTheme? splitButtonTheme, M3ESwitchTheme? switchTheme, M3ETabTheme? tabTheme, M3ETextFieldTheme? textFieldTheme, M3ETimePickerTheme? timePickerTheme, M3EToggleButtonTheme? toggleButtonTheme, M3EToggleButtonGroupTheme? toggleButtonGroupTheme, M3EToolbarTheme? toolbarTheme, M3ETooltipTheme? tooltipTheme}) M3EThemeData
Returns a copy with the given fields replaced.
deriveDarkTemplate() M3EThemeData
Builds a dark template from this light-oriented M3EThemeData.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toThemeData() ThemeData
Projects this theme onto a Material ThemeData.
withColorScheme(M3EColorScheme colorScheme) M3EThemeData
Returns a copy with colorScheme swapped and all component themes kept.

Operators

operator ==(Object other) bool
The equality operator.
inherited