M3EThemeExtension<T extends M3EThemeExtension<T>> class abstract

Base type for overridable component themes registered on M3EThemeData.

Implementers

Constructors

M3EThemeExtension()
Creates a theme extension.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() → T
Returns a copy with non-null fields replaced.
lerp(T? other, double t) → T
Linearly interpolates between this theme and other.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited