resolveOf static method
Resolves theme from the nearest scope, or null when none is present.
Implementation
static M3EThemeData? resolveOf(BuildContext context) {
return maybeOf(context)?.resolve(context);
}
Resolves theme from the nearest scope, or null when none is present.
static M3EThemeData? resolveOf(BuildContext context) {
return maybeOf(context)?.resolve(context);
}