components/badges/components/m3e_badge_layout library
Classes
- M3EBadgeLayout
- Anchors an indicator to the top edge of its content.
- M3EBadgeLayoutParentData
- Parent data for the badge layout.
- RenderM3EBadgeLayout
- Lays out badge content with its indicator anchored to the content box.