M3ERadiusAndPaddingMotion class
Animates shape and padding changes using a single spring progress value (0→1) that drives ALL corners and padding edges simultaneously.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- M3ERadiusAndPaddingMotion
Constructors
- M3ERadiusAndPaddingMotion({Key? key, required SpringMotion motion, required double internalLeft, required double internalRight, required double internalTop, required double internalBottom, required BorderRadius targetRadius, bool freezeTopLeft = false, bool freezeTopRight = false, bool freezeBottomLeft = false, bool freezeBottomRight = false, bool snapToTarget = false, required Widget builder(EdgeInsets padding, BorderRadius radius)})
-
M3ERadiusAndPaddingMotion.
const
Properties
- builder → Widget Function(EdgeInsets padding, BorderRadius radius)
-
Function.
final
- freezeBottomLeft → bool
-
freezeBottomLeft.
final
- freezeBottomRight → bool
-
freezeBottomRight.
final
- freezeTopLeft → bool
-
freezeTopLeft.
final
- freezeTopRight → bool
-
freezeTopRight.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalBottom → double
-
internalBottom.
final
- internalLeft → double
-
internalLeft.
final
- internalRight → double
-
internalRight.
final
- internalTop → double
-
internalTop.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- motion → SpringMotion
-
motion.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapToTarget → bool
-
When true, target changes apply instantly instead of springing in.
final
- targetRadius → BorderRadius
-
targetRadius.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< M3ERadiusAndPaddingMotion> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited