M3EButtonSize class
Standard size variants that map to Material 3 Expressive tokens.
Heights: xs=32dp, sm=40dp, md=56dp, lg=96dp, xl=136dp.
Used by M3EButton, M3EToggleButton, and M3EButtonGroup.
See also:
- M3EButton for the standard button widget
- M3EToggleButton for the toggle button widget
- M3EButtonGroup for the connected toggle button group
- Annotations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → double?
-
Custom height override.
final
- hPadding → double?
-
Custom horizontal padding override.
final
- iconGap → double?
-
Custom icon gap override.
final
- iconSize → double?
-
Custom icon size override.
final
- name → String
-
The name of the size variant.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double?
-
Custom width override.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- lg → const M3EButtonSize
- 96 dp height.
- md → const M3EButtonSize
- 56 dp height.
- sm → const M3EButtonSize
- 40 dp height.
- xl → const M3EButtonSize
- 136 dp height.
- xs → const M3EButtonSize
- 32 dp height.