M3EButtonMotion class

Spring-based motion configuration for M3EButton and M3EToggleButton.

Annotations

Constructors

M3EButtonMotion({required double stiffness, required double damping})
M3EButtonMotion.
const
M3EButtonMotion.custom(double stiffness, double damping)
custom.
factory

Properties

damping double
damping.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stiffness double
stiffness.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMotion() → SpringMotion
Converts this configuration to a SpringMotion.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

expressiveEffectsFast → const M3EButtonMotion
expressiveEffectsFast.
expressiveSpatialDefault → const M3EButtonMotion
Matches foundation M3EMotion.expressiveSpatialDefault (380 / 0.8).
expressiveSpatialPress → const M3EButtonMotion
Interactive press/release morph — same recipe as floating toolbar / FAB menu.
standard → const M3EButtonMotion
standard.
standardOverflow → const M3EButtonMotion
standardOverflow.
standardPopup → const M3EButtonMotion
standardPopup.
standardSpatialFast → const M3EButtonMotion
standardSpatialFast.