M3EButtonTheme class

Theme values for M3EButton.

Inheritance
Annotations

Constructors

M3EButtonTheme({double focusRingWidth = 2, double focusRingGap = M3EButtonConstants.kFocusRingGap, double minWidthFloor = 48, double dividerHeight = 24, double connectedInnerRadius = 8, double connectedPressedInnerRadius = 4})
M3EButtonTheme.
const

Properties

connectedInnerRadius double
connectedInnerRadius.
final
connectedPressedInnerRadius double
connectedPressedInnerRadius.
final
dividerHeight double
dividerHeight.
final
focusRingGap double
focusRingGap.
final
focusRingWidth double
focusRingWidth.
final
hashCode int
The hash code for this object.
no setterinherited
minWidthFloor double
minWidthFloor.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

container(M3EColorScheme scheme, M3EButtonStyle style) Color
container.
copyWith({double? focusRingWidth, double? focusRingGap, double? minWidthFloor, double? dividerHeight, double? connectedInnerRadius, double? connectedPressedInnerRadius}) M3EButtonTheme
Returns a copy with non-null fields replaced.
override
elevation(M3EButtonStyle style, Set<WidgetState> states) double
elevation.
equalizedMinWidth(M3EButtonSize size) double
equalizedMinWidth.
focusRingColor(M3EColorScheme scheme) Color
focusRingColor.
foreground(M3EColorScheme scheme, M3EButtonStyle style) Color
foreground.
hoveredRadius(M3EButtonSize size) double
hoveredRadius.
lerp(M3EButtonTheme? other, double t) M3EButtonTheme
Linearly interpolates between this theme and other.
override
measurements(M3EButtonSize size, {M3EButtonSize? override}) M3EButtonMeasurements
measurements.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
outline(M3EColorScheme scheme) Color
outline.
pressedRadius(M3EButtonSize size) double
pressedRadius.
squareRadius(M3EButtonSize size) double
squareRadius.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaults → const M3EButtonTheme
defaults.