freeScroll property
When false, a swipe advances one item and the scroll view does not drag. When true, the scroll view drags and snaps to the nearest item.
Defaults to false.
Implementation
final bool? freeScroll;
When false, a swipe advances one item and the scroll view does not drag. When true, the scroll view drags and snaps to the nearest item.
Defaults to false.
final bool? freeScroll;