M3ECarouselTheme class
Theme values for M3ECarousel.
- Inheritance
-
- Object
- M3EThemeExtension<
M3ECarouselTheme> - M3ECarouselTheme
- Annotations
Constructors
- M3ECarouselTheme({double uncontainedItemExtent = defaultUncontainedItemExtent, double uncontainedShrinkExtent = defaultUncontainedShrinkExtent, double borderRadiusValue = defaultBorderRadiusValue, int scrollAnimationDuration = defaultScrollAnimationDuration, int singleSwipeGestureSensitivityRange = defaultSingleSwipeGestureSensitivityRange, EdgeInsetsGeometry itemPadding = const EdgeInsets.all(4), double elevation = 0, Clip itemClipBehavior = Clip.antiAlias})
-
M3ECarouselTheme.
const
Properties
- borderRadius → BorderRadius
-
The borderRadius.
no setter
- borderRadiusValue → double
-
borderRadiusValue.
final
- elevation → double
-
elevation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemClipBehavior → Clip
-
itemClipBehavior.
final
- itemPadding → EdgeInsetsGeometry
-
itemPadding.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollAnimationDuration → int
-
scrollAnimationDuration.
final
- shape → ShapeBorder
-
The shape.
no setter
- singleSwipeGestureSensitivityRange → int
-
singleSwipeGestureSensitivityRange.
final
- uncontainedItemExtent → double
-
uncontainedItemExtent.
final
- uncontainedShrinkExtent → double
-
uncontainedShrinkExtent.
final
Methods
-
backgroundColor(
M3EColorScheme scheme) → Color - backgroundColor.
-
copyWith(
{double? uncontainedItemExtent, double? uncontainedShrinkExtent, double? borderRadiusValue, int? scrollAnimationDuration, int? singleSwipeGestureSensitivityRange, EdgeInsetsGeometry? itemPadding, double? elevation, Clip? itemClipBehavior}) → M3ECarouselTheme -
Returns a copy with non-null fields replaced.
override
-
lerp(
M3ECarouselTheme? other, double t) → M3ECarouselTheme -
Linearly interpolates between this theme and
other.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
overlayColor(
M3EColorScheme scheme) → WidgetStateProperty< Color?> - overlayColor.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultBorderRadiusValue → const double
- defaultBorderRadiusValue.
- defaults → const M3ECarouselTheme
- defaults.
- defaultScrollAnimationDuration → const int
- defaultScrollAnimationDuration.
- defaultSingleSwipeGestureSensitivityRange → const int
- defaultSingleSwipeGestureSensitivityRange.
- defaultUncontainedItemExtent → const double
- defaultUncontainedItemExtent.
- defaultUncontainedShrinkExtent → const double
- defaultUncontainedShrinkExtent.