M3ECarouselScrollHelper class abstract final

Scroll-step helpers for carousel frame navigation.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

nextStep({required M3ECarouselType type, required M3ECarouselHeroAlignment heroAlignment, required bool isExtended, required double uncontainedItemExtent, required List<int> layoutWeight, required double mainExtent, required int childrenLength, required int itemScrolled, required double prevScrollPosition, required int direction}) → ({int itemScrolled, double nextScrollPosition})?
Computes the next scroll position and updated itemScrolled for one step.