M3EChip class

A Material 3 Expressive chip.

A compact element for entering information, making selections, filtering or triggering actions. Filter and input chips can be selected; input chips can expose a trailing delete affordance.

Inheritance

Constructors

M3EChip({required String label, M3EChipType type = M3EChipType.assist, Widget? leading, bool selected = false, bool elevated = false, VoidCallback? onPressed, VoidCallback? onDeleted, Key? key})
M3EChip.
const

Properties

elevated bool
elevated.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
label.
final
leading Widget?
leading.
final
onDeleted VoidCallback?
onDeleted.
final
onPressed VoidCallback?
onPressed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
selected.
final
type M3EChipType
type.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited