Entry points for presenting M3E date picker dialogs.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
show(
BuildContext context, {DateTime? initialDate, required DateTime firstDate, required DateTime lastDate, DateTime? currentDate, M3EDatePickerEntryMode initialEntryMode = M3EDatePickerEntryMode.calendar, M3ESelectableDayPredicate? selectableDayPredicate, String? helpText, String? cancelText, String? confirmText, M3EDatePickerMode initialCalendarMode = M3EDatePickerMode.day, String? errorFormatText, String? errorInvalidText, String? fieldHintText, String? fieldLabelText, TextInputType? keyboardType, bool barrierDismissible = true, String? restorationId, ValueChanged< M3EDatePickerEntryMode> ? onDatePickerModeChange, EdgeInsets insetPadding = M3EDatePickerConstants.defaultInsetPadding}) → Future<DateTime?> - Shows a dialog to pick a single date.
-
showRange(
BuildContext context, {DateTime? initialStartDate, DateTime? initialEndDate, required DateTime firstDate, required DateTime lastDate, DateTime? currentDate, M3EDatePickerEntryMode initialEntryMode = M3EDatePickerEntryMode.calendar, M3ESelectableDayForRangePredicate? selectableDayPredicate, String? helpText, String? cancelText, String? confirmText, String? errorFormatText, String? errorInvalidText, String? fieldStartHintText, String? fieldEndHintText, String? fieldStartLabelText, String? fieldEndLabelText, bool barrierDismissible = true, String? restorationId, ValueChanged< M3EDatePickerEntryMode> ? onDatePickerModeChange, EdgeInsets insetPadding = M3EDatePickerConstants.defaultInsetPadding}) → Future<M3EDateRange?> - Shows a dialog to pick a date range.