M3EDialog class
A Material 3 Expressive dialog surface plus helpers to present dialogs.
Use M3EDialog.show for a standard centred dialog and M3EDialog.showFullScreen for a full-screen dialog.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- M3EDialog
Constructors
Properties
-
actions
→ List<
Widget> -
actions.
final
- bottomDivider → bool
-
Full-bleed divider above the actions row.
final
- content → Widget?
-
content.
final
- contentPadding → EdgeInsets?
-
contentPadding.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
icon.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
title.
final
- topDivider → bool
-
Full-bleed divider between the header and the section below it.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
show<
T> (BuildContext context, {required Widget dialog, bool barrierDismissible = true}) → Future< T?> - Presents a standard dialog and completes with the popped result.
-
showFullScreen<
T> (BuildContext context, {required String title, required Widget body, Widget? action}) → Future< T?> -
Presents a full-screen dialog with a header of
titleandaction. -
showSelectionScreen(
BuildContext context, {required String title, required List< String> options, bool multiSelect = false, List<String> initialSelection = const <String>[], String cancelLabel = _cancelLabel, String confirmLabel = _confirmLabel, Widget? icon, bool barrierDismissible = true}) → Future<List< String> ?> -
Presents a centred M3EDialog with selectable
options.