M3EDialogTheme class
Theme values for M3EDialog.
- Inheritance
-
- Object
- M3EThemeExtension<
M3EDialogTheme> - M3EDialogTheme
- Annotations
Constructors
- M3EDialogTheme({double minWidth = 280, double maxWidth = 560, EdgeInsets padding = const EdgeInsets.all(24), EdgeInsets screenMargin = const EdgeInsets.all(24), double entranceScale = 0.9, double iconSize = 24, double gapAfterIcon = 16, double gapAfterTitle = 16, double gapBeforeActions = 24, double actionGap = 8, double selectionItemHeight = 56, double fullScreenHeaderHeight = 64, double headerEdgeGap = 4, EdgeInsets closeButtonPadding = const EdgeInsets.all(12), double headerActionGap = 16, double scrimOpacity = 0.32})
-
M3EDialogTheme.
const
Properties
- actionGap → double
-
actionGap.
final
- borderRadius → BorderRadius
-
The borderRadius.
no setter
- closeButtonPadding → EdgeInsets
-
closeButtonPadding.
final
- entranceScale → double
-
entranceScale.
final
- fullScreenHeaderHeight → double
-
fullScreenHeaderHeight.
final
- gapAfterIcon → double
-
gapAfterIcon.
final
- gapAfterTitle → double
-
gapAfterTitle.
final
- gapBeforeActions → double
-
gapBeforeActions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerActionGap → double
-
headerActionGap.
final
- headerEdgeGap → double
-
headerEdgeGap.
final
- iconSize → double
-
iconSize.
final
- maxWidth → double
-
maxWidth.
final
- minWidth → double
-
minWidth.
final
- padding → EdgeInsets
-
padding.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenMargin → EdgeInsets
-
screenMargin.
final
- scrimOpacity → double
-
scrimOpacity.
final
- selectionItemHeight → double
-
Height of each selectable row in selection dialogs.
final
Methods
-
containerColor(
M3EColorScheme scheme) → Color - containerColor.
-
copyWith(
{double? minWidth, double? maxWidth, EdgeInsets? padding, EdgeInsets? screenMargin, double? entranceScale, double? iconSize, double? gapAfterIcon, double? gapAfterTitle, double? gapBeforeActions, double? actionGap, double? selectionItemHeight, double? fullScreenHeaderHeight, double? headerEdgeGap, EdgeInsets? closeButtonPadding, double? headerActionGap, double? scrimOpacity}) → M3EDialogTheme -
Returns a copy with non-null fields replaced.
override
-
fullScreenBackground(
M3EColorScheme scheme) → Color - fullScreenBackground.
-
lerp(
M3EDialogTheme? other, double t) → M3EDialogTheme -
Linearly interpolates between this theme and
other.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scrimColor(
M3EColorScheme scheme) → Color - scrimColor.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const M3EDialogTheme
- defaults.