M3EIconButtonTheme class
Theme values for M3EIconButton.
- Inheritance
-
- Object
- M3EThemeExtension<
M3EIconButtonTheme> - M3EIconButtonTheme
- Annotations
Constructors
- M3EIconButtonTheme({double outlineWidth = 1, Duration morphDuration = const Duration(milliseconds: 120), Curve morphCurve = Curves.easeOut})
-
M3EIconButtonTheme.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- morphCurve → Curve
-
morphCurve.
final
- morphDuration → Duration
-
morphDuration.
final
- outlineWidth → double
-
outlineWidth.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{double? outlineWidth, Duration? morphDuration, Curve? morphCurve}) → M3EIconButtonTheme -
Returns a copy with non-null fields replaced.
override
-
iconSize(
M3EIconButtonSize size) → double - iconSize.
-
lerp(
M3EIconButtonTheme? other, double t) → M3EIconButtonTheme -
Linearly interpolates between this theme and
other.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
radiusPressed(
M3EIconButtonSize size) → double - radiusPressed.
-
radiusRestRound(
M3EIconButtonSize size) → double - radiusRestRound.
-
radiusRestSquare(
M3EIconButtonSize size) → double - radiusRestSquare.
-
target(
M3EIconButtonSize size, M3EIconButtonWidth width) → Size - target.
-
toString(
) → String -
A string representation of this object.
inherited
-
visual(
M3EIconButtonSize size, M3EIconButtonWidth width) → Size - visual.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const M3EIconButtonTheme
- defaults.