M3EExpandableData class
A data container used to configure items for M3EExpandableList.
Constructors
Properties
- body → Widget?
-
A custom widget to display in the expanded body.
final
- bodyBuilder → Widget Function(BuildContext context)?
-
A builder function to create the body content dynamically.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- leading → Widget?
-
An optional leading widget for the header (e.g., an Icon or CircleAvatar).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
An optional text-only subtitle.
final
- subtitleMaxLines → int?
-
Maximum number of lines for the subtitle when collapsed.
final
-
subtitleStyle
→ List<
TextStyle> ? -
Optional custom text styles for the subtitle.
final
- title → String
-
The main title text shown in the header.
final
-
titleStyle
→ List<
TextStyle> ? -
Optional custom text styles for the title.
final
- trailing → Widget?
-
An optional trailing widget for the header.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited