components/lists/m3e_lists library

Classes

M3ECardList
A Material 3 interactive card list with dynamically rounded corners.
M3EDismissibleColumn
A dismissible Material 3 list backed by a Column.
M3EDismissibleList
M3EDismissibleList.
M3EDismissibleListStyle
Immutable visual and interaction configuration for dismissible M3E lists.
M3EDismissibleSlot
Lightweight per-item bookkeeping for a dismissible card slot.
M3EExpandableData
A data container used to configure items for M3EExpandableList.
M3EExpandableExpanded
Expanded content for an expandable list item.
M3EExpandableItem
M3EExpandableItem.
M3EExpandableList
A spring-animated expandable card list.
M3EExpandableStyle
Visual style configuration for M3EExpandableList.
M3EListCardListTheme
Theme values for M3ECardList.
M3EListDismissibleTheme
Theme values for dismissible list widgets.
M3EListExpandableTheme
Theme values for expandable list widgets.
M3EListFeatureScope
Provides list selection/reorder config to descendants (e.g. list items).
M3EListItem
A Material 3 Expressive list item.
M3EListItemIndex
Row index for the current list item under a feature scope.
M3EListItemScope
Marks descendants as content inside a card-backed list surface.
M3EListItemTheme
Theme values for M3EListItem.
M3EListReorderState
Visual and motion defaults for list reorder.
M3EListSelectionState
Visual and interaction defaults for list selection.
M3EListSwipeAction
A swipe action revealed beside a dismissible list row.
M3EListTheme
Theme values for list-family widgets.
M3EMeasureSize
Reports the rendered size of child to onChange after each layout.

Enums

M3ECardPosition
The position of a card within a list, used to determine its corner radii.
M3EExpandableExpandedType
How expanded content under an expandable row is presented.
M3EExpandableIconPlacement
Determines the placement of the expand/collapse icon in the header.
M3EListSelectionMode
Selection cardinality for list selection.
M3EListSelectionTrigger
Gesture that toggles list selection.

Mixins

M3EDismissibleCardBuildMixin<T extends StatefulWidget>
M3EDismissibleCardBuildMixin.
M3EDismissibleCardDragMixin<T extends StatefulWidget>
M3EDismissibleCardDragMixin.
M3EDismissibleCardMixin<T extends StatefulWidget>
M3EDismissibleCardMixin.

Functions

calculateCardPosition(int index, int total) M3ECardPosition
Internal helper to calculate M3ECardPosition based on index and total.
calculateCardRadius({required M3ECardPosition position, required double outerRadius, required double innerRadius, bool embedded = false, bool closeBottom = false}) BorderRadius
Internal helper to calculate BorderRadius based on M3ECardPosition.

Typedefs

M3EExpandableBodyBuilder = Widget Function(BuildContext context, int index, double progress)
M3EExpandableBodyBuilder.
M3EExpandableHeaderBuilder = Widget Function(BuildContext context, int index, double progress)
M3EExpandableHeaderBuilder.