listPadding property
Padding for the scrollable list itself.
Adds empty space at the edges of the list. Distinct from margin, which wraps the entire list, and padding, which goes inside each card.
Only used by M3ECardList.builder.
Implementation
final EdgeInsetsGeometry? listPadding;