M3EExpandableStyle class
Visual style configuration for M3EExpandableList.
- Annotations
Constructors
- M3EExpandableStyle({double outerRadius = M3EListExpandableTheme.defaultOuterRadius, double innerRadius = M3EListExpandableTheme.defaultInnerRadius, double hoverRadius = M3EListExpandableTheme.defaultHoverRadius, double pressedRadius = M3EListExpandableTheme.defaultPressedRadius, double gap = M3EListExpandableTheme.defaultGap, double? expandedRadius, Color? color, BorderSide? border, double elevation = 0, EdgeInsetsGeometry? headerPadding, EdgeInsetsGeometry? bodyPadding, double titleSubtitleGap = M3EListExpandableTheme.defaultTitleSubtitleGap, EdgeInsetsGeometry? margin, EdgeInsetsGeometry iconPadding = M3EListExpandableTheme.defaultIconPadding, double iconRotationAngle = M3EListExpandableTheme.defaultIconRotationAngle, Widget? expandIcon = const Icon(M3EIcons.expand_more_rounded), Widget? collapseIcon = const Icon(M3EIcons.expand_more_rounded), M3EExpandableIconPlacement iconPlacement = M3EExpandableIconPlacement.right, bool useInkWell = true, bool tapHeaderToToggle = true, bool tapBodyToExpand = false, bool tapBodyToCollapse = false, CrossAxisAlignment headerAlignment = CrossAxisAlignment.start, AlignmentGeometry bodyAlignment = Alignment.topLeft, M3EHapticFeedback haptic = M3EHapticFeedback.none, Color? splashColor, Color? highlightColor, InteractiveInkFeatureFactory? splashFactory, bool enableFeedback = true, bool tapIconToToggle = false, String? expandTooltip = M3EListExpandableTheme.defaultExpandTooltip, String? collapseTooltip = M3EListExpandableTheme.defaultCollapseTooltip})
-
M3EExpandableStyle.
const
- M3EExpandableStyle.fromTheme(M3EListExpandableTheme theme)
-
Builds a style from the given M3EListExpandableTheme.
factory
Properties
- bodyAlignment → AlignmentGeometry
-
The alignment of the body content.
final
- bodyPadding → EdgeInsetsGeometry?
-
Padding applied inside each body.
final
- border → BorderSide?
-
Border drawn around each card.
final
- collapseIcon → Widget?
-
The icon in the expanded state. Set to null to hide the default icon.
final
- collapseTooltip → String?
-
The tooltip message displayed when hovering over or long-pressing the collapse icon.
final
- color → Color?
-
Background colour for each card.
final
- elevation → double
-
Elevation of the card.
final
- enableFeedback → bool
-
Whether detected gestures should provide acoustic / haptic feedback.
final
- expandedRadius → double?
-
Border radius applied uniformly to the entire card when expanded.
final
- expandIcon → Widget?
-
The icon in the collapsed state. Set to null to hide the default icon.
final
- expandTooltip → String?
-
The tooltip message displayed when hovering over or long-pressing the expand icon.
final
- gap → double
-
Gap between cards.
final
- haptic → M3EHapticFeedback
-
Haptic feedback level on tap.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- headerAlignment → CrossAxisAlignment
-
The alignment of the header relative to the expand icon.
final
- headerPadding → EdgeInsetsGeometry?
-
Padding applied inside each header.
final
- highlightColor → Color?
-
Ink highlight colour.
final
- hoverRadius → double
-
Inner radius applied when the card is hovered.
final
- iconPadding → EdgeInsetsGeometry
-
Expand icon padding.
final
- iconPlacement → M3EExpandableIconPlacement
-
Expand icon placement.
final
- iconRotationAngle → double
-
Icon rotation angle in clockwise radians.
final
- innerRadius → double
-
Inner radius for middle items.
final
- margin → EdgeInsetsGeometry?
-
Outer margin around each card.
final
- outerRadius → double
-
Outer radius for the first and last item (and single items).
final
- pressedRadius → double
-
Inner radius applied when the card is pressed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- splashColor → Color?
-
Ink splash colour.
final
- splashFactory → InteractiveInkFeatureFactory?
-
Splash factory.
final
- tapBodyToCollapse → bool
-
If true, the body can be clicked by the user to collapse.
final
- tapBodyToExpand → bool
-
If true, the body can be clicked by the user to expand.
final
- tapHeaderToToggle → bool
-
If true, the header can be clicked by the user to expand or collapse.
final
- tapIconToToggle → bool
-
If true, toggling expansion/collapse is only possible by tapping the icon.
final
- titleSubtitleGap → double
-
Gap between simple-mode title and subtitle/body text.
final
- useInkWell → bool
-
Whether InkWell will be used in the header for a ripple effect.
final
Methods
-
copyWith(
{double? outerRadius, double? innerRadius, double? hoverRadius, double? pressedRadius, double? gap, double? expandedRadius, Color? color, BorderSide? border, double? elevation, EdgeInsetsGeometry? headerPadding, EdgeInsetsGeometry? bodyPadding, double? titleSubtitleGap, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? iconPadding, double? iconRotationAngle, Widget? expandIcon, Widget? collapseIcon, M3EExpandableIconPlacement? iconPlacement, bool? useInkWell, bool? tapHeaderToToggle, bool? tapBodyToExpand, bool? tapBodyToCollapse, CrossAxisAlignment? headerAlignment, AlignmentGeometry? bodyAlignment, M3EHapticFeedback? haptic, Color? splashColor, Color? highlightColor, InteractiveInkFeatureFactory? splashFactory, bool? enableFeedback, bool? tapIconToToggle, String? expandTooltip, String? collapseTooltip}) → M3EExpandableStyle - Creates a copy of this decoration with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override