M3EMenuEntry class
Standard action row (Compose DropdownMenuItem).
- Inheritance
-
- Object
- M3EMenuNode
- M3EMenuEntry
- Annotations
Constructors
- M3EMenuEntry({required String label, Widget? leading, Widget? trailing, String? trailingText, Widget? badge, String? supportingText, VoidCallback? onPressed, bool enabled = true, bool isDestructive = false, Object? value, M3EMenuItemShape shape = M3EMenuItemShape.standalone})
-
M3EMenuEntry.
const
Properties
- badge → Widget?
-
Optional status chip before trailing icon/text.
final
- enabled → bool
-
enabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDestructive → bool
-
isDestructive.
final
- label → String
-
label.
final
- leading → Widget?
-
leading.
final
- onPressed → VoidCallback?
-
onPressed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → M3EMenuItemShape
-
shape.
final
- supportingText → String?
-
supportingText.
final
- trailing → Widget?
-
trailing.
final
- trailingText → String?
-
Shortcut / secondary trailing label (e.g.
⌘C).final - value → Object?
-
Optional result returned by
showM3EMenuwhen this entry is chosen.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited