M3EMenuToggleable class

Toggleable row (Compose checked menu item).

Inheritance
Annotations

Constructors

M3EMenuToggleable({required String label, required bool checked, Widget? leading, Widget? trailing, String? trailingText, Widget? badge, String? supportingText, ValueChanged<bool>? onChanged, bool enabled = true, M3EMenuItemShape shape = M3EMenuItemShape.standalone})
M3EMenuToggleable.
const

Properties

badge → Widget?
badge.
final
checked → bool
checked.
final
enabled → bool
enabled.
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
label.
final
leading → Widget?
leading.
final
onChanged → ValueChanged<bool>?
onChanged.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → M3EMenuItemShape
shape.
final
supportingText → String?
supportingText.
final
trailing → Widget?
trailing.
final
trailingText → String?
trailingText.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited