M3EMenuWidget class

Row whose body is an arbitrary child (host-provided content).

Inheritance
Annotations

Constructors

M3EMenuWidget({required Widget child, Object? value, VoidCallback? onPressed, bool enabled = true, bool selected = false, String? semanticLabel, M3EMenuItemShape shape = M3EMenuItemShape.standalone})
M3EMenuWidget.
const

Properties

child Widget
child.
final
enabled bool
enabled.
final
hashCode int
The hash code for this object.
no setterinherited
onPressed VoidCallback?
onPressed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
selected.
final
semanticLabel String?
semanticLabel.
final
shape M3EMenuItemShape
shape.
final
value Object?
value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited