M3ENavigationRailSection class
Section groups a header and a list of destinations. One class per file.
Constructors
-
Creates a M3ENavigationRailSection.
const
Properties
-
destinations
→ List<
M3ENavigationRailDestination> -
Destinations shown in this section.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget?
-
Optional header widget displayed above the destinations.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited