components/refresh_indicator/enums/m3e_refresh_status library
Enums
- M3ERefreshStatus
-
The lifecycle states an
M3ERefreshIndicatormoves through. - M3ERefreshTriggerMode
- Controls where a pull is allowed to start a refresh.
Typedefs
-
M3ERefreshCallback
= Future<
void> Function() - Signature for the callback invoked when the user triggers a refresh.