M3ESearchBarInput class
Shared editable search field used by M3ESearchBar and the search view header.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- M3ESearchBarInput
Constructors
-
M3ESearchBarInput({required TextEditingController controller, required FocusNode focusNode, required String? hintText, required bool enabled, required bool readOnly, required bool autoFocus, required TextStyle textStyle, required TextStyle hintStyle, required Color cursorColor, required Color selectionColor, GestureTapCallback? onTap, TapRegionCallback? onTapOutside, ValueChanged<
String> ? onChanged, ValueChanged<String> ? onSubmitted, TextCapitalization textCapitalization = TextCapitalization.none, TextInputAction? textInputAction, TextInputType? keyboardType, EdgeInsets scrollPadding = const EdgeInsets.all(20), EditableTextContextMenuBuilder contextMenuBuilder = m3eDefaultSearchContextMenuBuilder, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, EdgeInsetsGeometry contentPadding = EdgeInsets.zero, Key? key}) -
M3ESearchBarInput.
const
Properties
- autoFocus → bool
-
autoFocus.
final
- contentPadding → EdgeInsetsGeometry
-
contentPadding.
final
- contextMenuBuilder → EditableTextContextMenuBuilder
-
contextMenuBuilder.
final
- controller → TextEditingController
-
controller.
final
- cursorColor → Color
-
cursorColor.
final
- enabled → bool
-
enabled.
final
- focusNode → FocusNode
-
focusNode.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintStyle → TextStyle
-
hintStyle.
final
- hintText → String?
-
hintText.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
keyboardType.
final
-
onChanged
→ ValueChanged<
String> ? -
onChanged.
final
-
onSubmitted
→ ValueChanged<
String> ? -
onSubmitted.
final
- onTap → GestureTapCallback?
-
onTap.
final
- onTapOutside → TapRegionCallback?
-
onTapOutside.
final
- readOnly → bool
-
readOnly.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollPadding → EdgeInsets
-
scrollPadding.
final
- selectionColor → Color
-
selectionColor.
final
- smartDashesType → SmartDashesType?
-
smartDashesType.
final
- smartQuotesType → SmartQuotesType?
-
smartQuotesType.
final
- textCapitalization → TextCapitalization
-
textCapitalization.
final
- textInputAction → TextInputAction?
-
textInputAction.
final
- textStyle → TextStyle
-
textStyle.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< M3ESearchBarInput> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited