M3ESegmentedButtonTheme class
Theme values for M3ESegmentedButton.
- Inheritance
-
- Object
- M3EThemeExtension<
M3ESegmentedButtonTheme> - M3ESegmentedButtonTheme
- Annotations
Constructors
Properties
- borderRadius → BorderRadius
-
The borderRadius.
no setter
- borderWidth → double
-
borderWidth.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
height.
final
- iconLabelGap → double
-
iconLabelGap.
final
- iconSize → double
-
iconSize.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segmentHorizontalPadding → double
-
segmentHorizontalPadding.
final
Methods
-
backgroundColor(
M3EColorScheme scheme, {required bool selected}) → Color? - backgroundColor.
-
copyWith(
{double? height, double? iconSize, double? segmentHorizontalPadding, double? iconLabelGap, double? borderWidth}) → M3ESegmentedButtonTheme -
Returns a copy with non-null fields replaced.
override
-
foregroundColor(
M3EColorScheme scheme, {required bool selected}) → Color - foregroundColor.
-
lerp(
M3ESegmentedButtonTheme? other, double t) → M3ESegmentedButtonTheme -
Linearly interpolates between this theme and
other.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const M3ESegmentedButtonTheme
- defaults.