M3ESideSheetLabels class
Accessibility strings for a side sheet.
The sheet itself reads as a dialog named by its headline.
- Annotations
Constructors
- M3ESideSheetLabels({String close = M3ESideSheetStrings.close, String back = M3ESideSheetStrings.back, String scrim = M3ESideSheetStrings.dismiss})
-
M3ESideSheetLabels.
const
Properties
- back → String
-
Back icon button tooltip and label.
final
- close → String
-
Close icon button tooltip and label.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrim → String
-
Scrim label (modal only).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited