M3ESplitButtonItem<T> class
A single selectable entry in an M3ESplitButton menu.
Constructors
- M3ESplitButtonItem({required T value, required Object child, bool enabled = true})
-
M3ESplitButtonItem.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited