M3ETextField class

A Material 3 Expressive text field.

Supports the filled and outlined variants, a floating label, leading and trailing widgets, supporting text and an error state. The label floats on focus or when the field holds text, and the active indicator/outline and label recolor to reflect focus and error states.

Inheritance

Constructors

M3ETextField({TextEditingController? controller, FocusNode? focusNode, String? label, String? supportingText, String? errorText, Widget? leading, Widget? trailing, M3ETextFieldVariant variant = M3ETextFieldVariant.filled, bool obscureText = false, bool enabled = true, TextInputType? keyboardType, TextInputAction? textInputAction, ValueChanged<String>? onChanged, ValueChanged<String>? onSubmitted, TapRegionCallback? onTapOutside, int maxLines = 1, Key? key})
M3ETextField.
const

Properties

controller TextEditingController?
controller.
final
enabled bool
enabled.
final
errorText String?
errorText.
final
focusNode FocusNode?
focusNode.
final
hasError bool
The hasError.
no setter
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType TextInputType?
keyboardType.
final
label String?
label.
final
leading Widget?
leading.
final
maxLines int
maxLines.
final
obscureText bool
obscureText.
final
onChanged ValueChanged<String>?
onChanged.
final
onSubmitted ValueChanged<String>?
onSubmitted.
final
onTapOutside TapRegionCallback?
onTapOutside.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportingText String?
supportingText.
final
textInputAction TextInputAction?
textInputAction.
final
trailing Widget?
trailing.
final
variant M3ETextFieldVariant
variant.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<M3ETextField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited