M3ETextFieldTheme class
Theme values for M3ETextField.
- Inheritance
-
- Object
- M3EThemeExtension<
M3ETextFieldTheme> - M3ETextFieldTheme
- Annotations
Constructors
- M3ETextFieldTheme({double minHeight = 56, double contentHeight = 48, double labelRestingOffset = 12, EdgeInsets horizontalPadding = const EdgeInsets.symmetric(horizontal: 16), double iconSize = 24, double iconGap = 12, double labelFloatingTopPadding = 8, double labelRestingTopPadding = 16, double labelBottomPadding = 2, double selectionOpacity = 0.4, EdgeInsets supportingTextPadding = const EdgeInsets.only(left: 16, top: 4, right: 16)})
-
M3ETextFieldTheme.
const
Properties
- contentHeight → double
-
contentHeight.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalPadding → EdgeInsets
-
horizontalPadding.
final
- iconGap → double
-
iconGap.
final
- iconSize → double
-
iconSize.
final
- labelBottomPadding → double
-
labelBottomPadding.
final
- labelFloatingTopPadding → double
-
labelFloatingTopPadding.
final
- labelRestingOffset → double
-
labelRestingOffset.
final
- labelRestingTopPadding → double
-
labelRestingTopPadding.
final
- minHeight → double
-
minHeight.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionOpacity → double
-
selectionOpacity.
final
- supportingTextPadding → EdgeInsets
-
supportingTextPadding.
final
Methods
-
accentColor(
M3EColorScheme scheme, {required bool enabled, required bool hasError}) → Color - accentColor.
-
copyWith(
{double? minHeight, double? contentHeight, double? labelRestingOffset, EdgeInsets? horizontalPadding, double? iconSize, double? iconGap, double? labelFloatingTopPadding, double? labelRestingTopPadding, double? labelBottomPadding, double? selectionOpacity, EdgeInsets? supportingTextPadding}) → M3ETextFieldTheme -
Returns a copy with non-null fields replaced.
override
-
decoration(
M3EColorScheme scheme, {required Color accent, required bool outlined, required bool focused, required bool hasError}) → BoxDecoration - decoration.
-
lerp(
M3ETextFieldTheme? other, double t) → M3ETextFieldTheme -
Linearly interpolates between this theme and
other.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const M3ETextFieldTheme
- defaults.