M3ETime class
An immutable wall-clock time in 24-hour form.
- Annotations
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- hour → int
-
hour.
final
- hourOf12 → int
-
The hour in 12-hour form (1..12).
no setter
- isPm → bool
-
Whether the time falls in the afternoon (12:00 onward).
no setter
- minute → int
-
minute.
final
- minuteLabel → String
-
A zero-padded "HH:MM" style label using the 12-hour hour.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? hour, int? minute}) → M3ETime - copyWith.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override