M3EButtonGroup class
A horizontal (or vertical) row of M3EToggleButtons with optional neighbor-squish animation and connected-group shape morphing.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- M3EButtonGroup
Constructors
-
M3EButtonGroup({Key? key, required List<
M3EButtonGroupAction> actions, M3EButtonGroupType type = M3EButtonGroupType.standard, M3EButtonShape shape = M3EButtonShape.round, M3EButtonSize size = M3EButtonSize.sm, M3EButtonStyle style = M3EButtonStyle.filled, M3EButtonGroupDensity density = M3EButtonGroupDensity.regular, double? spacing, Axis direction = Axis.horizontal, int? selectedIndex, Set<int> ? selectedIndices, ValueChanged<int?> ? onSelectedIndexChanged, ValueChanged<Set< ? onSelectedIndicesChanged, bool neighborSquish = true, double expandedRatio = 0.15, M3EHapticFeedback haptic = M3EHapticFeedback.none, bool enableFeedback = true, M3EToggleButtonDecoration? decoration, String? semanticLabel, Clip clipBehavior = Clip.none, M3EButtonGroupOverflow overflow = M3EButtonGroupOverflow.scroll, Widget? overflowIcon, M3EOverflowPopupDecoration overflowPopupDecoration = const M3EOverflowPopupDecoration(), M3EOverflowBottomSheetDecoration overflowBottomSheetDecoration = const M3EOverflowBottomSheetDecoration(), M3EButtonGroupOverflowMenuStyle overflowMenuStyle = M3EButtonGroupOverflowMenuStyle.popup, M3EOverflowStrategy? overflowStrategy})int> > -
const.
const
Properties
-
actions
→ List<
M3EButtonGroupAction> -
final.
final
- clipBehavior → Clip
-
final.
final
- decoration → M3EToggleButtonDecoration?
-
final.
final
- density → M3EButtonGroupDensity
-
final.
final
- direction → Axis
-
final.
final
- enableFeedback → bool
-
final.
final
- expandedRatio → double
-
final.
final
- haptic → M3EHapticFeedback
-
final.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- neighborSquish → bool
-
final.
final
-
onSelectedIndexChanged
→ ValueChanged<
int?> ? -
final.
final
-
onSelectedIndicesChanged
→ ValueChanged<
Set< ?int> > -
final.
final
- overflow → M3EButtonGroupOverflow
-
final.
final
- overflowBottomSheetDecoration → M3EOverflowBottomSheetDecoration
-
final.
final
- overflowIcon → Widget?
-
final.
final
- overflowMenuStyle → M3EButtonGroupOverflowMenuStyle
-
final.
final
- overflowPopupDecoration → M3EOverflowPopupDecoration
-
final.
final
- overflowStrategy → M3EOverflowStrategy?
-
final.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedIndex → int?
-
final.
final
-
selectedIndices
→ Set<
int> ? -
final.
final
- semanticLabel → String?
-
final.
final
- shape → M3EButtonShape
-
final.
final
- size → M3EButtonSize
-
final.
final
- spacing → double?
-
final.
final
- style → M3EButtonStyle
-
final.
final
- type → M3EButtonGroupType
-
final.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< M3EButtonGroup> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited