M3EToggleButtonTheme class

Theme values for M3EToggleButton.

Inheritance
Annotations

Constructors

M3EToggleButtonTheme({double labelSlideDistance = 10})
M3EToggleButtonTheme.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
labelSlideDistance double
labelSlideDistance.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? labelSlideDistance}) M3EToggleButtonTheme
Returns a copy with non-null fields replaced.
override
lerp(M3EToggleButtonTheme? other, double t) M3EToggleButtonTheme
Linearly interpolates between this theme and other.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaults → const M3EToggleButtonTheme
defaults.