M3EToolbarScrollBehavior class

Integrates scroll notifications with a M3EToolbarVisibilityController.

Constructors

M3EToolbarScrollBehavior({required M3EToolbarExitDirection exitDirection, required M3EToolbarVisibilityController controller})
M3EToolbarScrollBehavior.
const
M3EToolbarScrollBehavior.exitAlways({M3EToolbarExitDirection exitDirection = M3EToolbarExitDirection.bottom, M3EToolbarVisibilityController? controller})
Creates a behavior that exits while scrolling (opt-in).
factory

Properties

controller M3EToolbarVisibilityController
Shared visibility state (manual M3EToolbarVisibilityController.show / M3EToolbarVisibilityController.hide or scroll-driven).
final
exitDirection M3EToolbarExitDirection
Direction the toolbar slides when hiding.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited