M3ETooltipTheme class
Theme values for M3ETooltip.
- Inheritance
-
- Object
- M3EThemeExtension<
M3ETooltipTheme> - M3ETooltipTheme
- Annotations
Constructors
- M3ETooltipTheme({double anchorOffset = 4, double plainMaxWidth = 200, double plainMinHeight = 24, EdgeInsets plainPadding = const EdgeInsets.symmetric(horizontal: 8, vertical: 4), double richMaxWidth = 320, EdgeInsets richPadding = const EdgeInsets.fromLTRB(16, 12, 16, 8), double richTitleGap = 4, double richActionsGap = 12, double richElevation = M3EElevation.level2, Duration plainDismissDelay = Duration.zero, Duration richDismissDelay = const Duration(milliseconds: 1500), double placementStep = 8})
-
M3ETooltipTheme.
const
Properties
- anchorOffset → double
-
Gap between the target and the tooltip. Spec: 4dp (visual boundary).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- placementStep → double
-
Step size when shifting to stay on-screen. Spec: 8dp.
final
- plainBorderRadius → BorderRadius
-
Plain corner radius. Spec: Extra small (4dp).
no setter
- plainDismissDelay → Duration
-
Delay after leaving the target before hiding a plain tooltip.
Default: instant (Duration.zero).
final
- plainMaxWidth → double
-
Max width for plain tooltips.
final
- plainMinHeight → double
-
Min height for plain tooltips. Spec: 24dp.
final
- plainPadding → EdgeInsets
-
Plain padding. Spec-aligned: horizontal 8, vertical 4 (with plainMinHeight).
final
- richActionsGap → double
-
Gap between supporting text and actions. Spec-aligned: 12dp.
final
- richBorderRadius → BorderRadius
-
Rich corner radius. Spec: Medium (12dp).
no setter
- richDismissDelay → Duration
-
Delay after leaving the target before hiding a transient rich tooltip.
Default: 1.5s so actions remain reachable.
final
- richElevation → double
-
Rich container elevation. Spec inference: Level 2.
final
- richMaxWidth → double
-
Max width for rich tooltips.
final
- richPadding → EdgeInsets
-
Rich padding. Spec: top 12, bottom 8, left/right 16.
final
- richTitleGap → double
-
Gap between subhead and supporting text. Spec: 4dp.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{double? anchorOffset, double? plainMaxWidth, double? plainMinHeight, EdgeInsets? plainPadding, double? richMaxWidth, EdgeInsets? richPadding, double? richTitleGap, double? richActionsGap, double? richElevation, Duration? plainDismissDelay, Duration? richDismissDelay, double? placementStep}) → M3ETooltipTheme -
Returns a copy with non-null fields replaced.
override
-
lerp(
M3ETooltipTheme? other, double t) → M3ETooltipTheme -
Linearly interpolates between this theme and
other.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
plainContainerColor(
M3EColorScheme scheme) → Color - Plain container. Spec: Inverse surface.
-
plainMessageStyle(
M3ETypeScale type, M3EColorScheme scheme) → TextStyle - Plain supporting text. Spec: Inverse on surface / bodySmall metrics.
-
richBodyStyle(
M3ETypeScale type, M3EColorScheme scheme) → TextStyle - Rich supporting text. Spec: On surface variant / bodyMedium metrics.
-
richContainerColor(
M3EColorScheme scheme) → Color - Rich container. Spec: Surface container.
-
richTitleStyle(
M3ETypeScale type, M3EColorScheme scheme) → TextStyle - Rich subhead. Spec: On surface variant / titleSmall metrics.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const M3ETooltipTheme
- defaults.