M3ETooltipTheme class
Theme values for M3ETooltip.
- Inheritance
-
- Object
- M3EThemeExtension<
M3ETooltipTheme> - M3ETooltipTheme
- Annotations
Constructors
- M3ETooltipTheme({double anchorOffset = 4, double plainMaxWidth = 200, EdgeInsets plainPadding = const EdgeInsets.symmetric(horizontal: 8, vertical: 4), double richMaxWidth = 320, EdgeInsets richPadding = const EdgeInsets.all(16), double richTitleGap = 4, double richActionsGap = 12, double richElevation = M3EElevation.level2})
-
M3ETooltipTheme.
const
Properties
- anchorOffset → double
-
anchorOffset.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- plainBorderRadius → BorderRadius
-
The plainBorderRadius.
no setter
- plainDismissDelay → Duration
-
The plainDismissDelay.
no setter
- plainMaxWidth → double
-
plainMaxWidth.
final
- plainPadding → EdgeInsets
-
plainPadding.
final
- richActionsGap → double
-
richActionsGap.
final
- richBorderRadius → BorderRadius
-
The richBorderRadius.
no setter
- richElevation → double
-
richElevation.
final
- richMaxWidth → double
-
richMaxWidth.
final
- richPadding → EdgeInsets
-
richPadding.
final
- richTitleGap → double
-
richTitleGap.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{double? anchorOffset, double? plainMaxWidth, EdgeInsets? plainPadding, double? richMaxWidth, EdgeInsets? richPadding, double? richTitleGap, double? richActionsGap, double? richElevation}) → M3ETooltipTheme -
Returns a copy with non-null fields replaced.
override
-
lerp(
M3ETooltipTheme? other, double t) → M3ETooltipTheme -
Linearly interpolates between this theme and
other.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
plainContainerColor(
M3EColorScheme scheme) → Color - plainContainerColor.
-
plainMessageStyle(
M3ETypeScale type, M3EColorScheme scheme) → TextStyle - plainMessageStyle.
-
richBodyStyle(
M3ETypeScale type, M3EColorScheme scheme) → TextStyle - richBodyStyle.
-
richContainerColor(
M3EColorScheme scheme) → Color - richContainerColor.
-
richTitleStyle(
M3ETypeScale type, M3EColorScheme scheme) → TextStyle - richTitleStyle.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const M3ETooltipTheme
- defaults.