build method
Builds the component subtree with an adaptive theme dependency.
Implementation
@override
/// Builds the component subtree with an adaptive theme dependency.
Widget build(BuildContext context) {
final M3EInheritedTheme? inherited = context
.dependOnInheritedWidgetOfExactType<M3EInheritedTheme>();
if (inherited == null) {
M3EThemeScope.resolveForComponent(context);
}
return builder(context);
}