M3EFocusRingTheme class
Shared tokens for the Material 3 Expressive keyboard focus ring.
- Inheritance
-
- Object
- M3EThemeExtension<
M3EFocusRingTheme> - M3EFocusRingTheme
- Annotations
Constructors
- M3EFocusRingTheme({Color? color, double width = 2, double gap = 2})
-
Creates focus ring theme tokens.
const
Properties
- color → Color?
-
Optional override; when null, resolves to M3EColorScheme.primary.
final
- gap → double
-
Gap between the component edge and the focus ring outline (dp).
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- outset → double
-
Total outset past the component edge (
gap + width).no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double
-
Stroke width of the focus ring outline (dp).
final
Methods
-
copyWith(
{Color? color, bool clearColor = false, double? width, double? gap}) → M3EFocusRingTheme -
Returns a copy with non-null fields replaced.
override
-
lerp(
M3EFocusRingTheme? other, double t) → M3EFocusRingTheme -
Linearly interpolates between this theme and
other.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveColor(
M3EColorScheme scheme) → Color -
Resolved ring color for
scheme. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- defaults → const M3EFocusRingTheme
- Package defaults.