focusable property
Whether this surface is a keyboard Tab stop.
When false, pointer activation still works but Tab skips the surface (use for controls embedded in a focusable parent row).
Implementation
final bool focusable;
Whether this surface is a keyboard Tab stop.
When false, pointer activation still works but Tab skips the surface (use for controls embedded in a focusable parent row).
final bool focusable;