Material 3 elevation tokens expressed in logical pixels (dp).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- level0 → const double
- Flat surface with no elevation shadow.
- level1 → const double
- Lowest raised surface (1dp).
- level2 → const double
- Low raised surface (3dp).
- level3 → const double
- Medium raised surface (6dp).
- level4 → const double
- High raised surface (8dp).
- level5 → const double
- Highest raised surface (12dp).