Shared focus helpers for M3E input components.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
tapOutsideHandler(
FocusNode focusNode) → TapRegionCallback -
Builds a TapRegionCallback that unfocuses
focusNode. -
unfocusOnTapOutside(
FocusNode focusNode, PointerDownEvent event) → void -
Default EditableText.onTapOutside handler that unfocuses
focusNode.