M3ESpring class
A serialisable description of a Material 3 Expressive spring.
damping is expressed as a damping ratio where 1.0 is critically damped
(no overshoot) and values below 1.0 produce an expressive overshoot.
- Available extensions
- Annotations
Constructors
Properties
- damping → double
-
Damping ratio.
1.0is critically damped; lower values overshoot.final - hashCode → int
-
Hash code for this spring.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stiffness → double
-
Spring stiffness. Higher values settle faster.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDescription(
) → SpringDescription - Builds a SpringDescription for a unit mass.
-
toMotion(
) → SpringMotion -
Available on M3ESpring, provided by the M3EDropdownSpringMotion extension
toMotion. -
toMotion(
) → SpringMotion -
Available on M3ESpring, provided by the M3EExpandableSpringMotion extension
toMotion. -
toMotion(
) → SpringMotion -
Available on M3ESpring, provided by the M3EMenuSpringMotion extension
toMotion. -
toMotion(
) → SpringMotion -
Available on M3ESpring, provided by the M3EToolbarSpringMotion extension
Matches m3e_core floating toolbar: expressive spatial base + token values. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
Equality based on public fields.
override