M3EShapeContainer class
A box clipped to an M3EShapeKind polygon.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- M3EShapeContainer
Constructors
- M3EShapeContainer({Key? key, required M3EShapeKind kind, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Creates a shaped container.
const
- M3EShapeContainer.arch({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Arch.
const
- M3EShapeContainer.arrow({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Arrow.
const
- M3EShapeContainer.boom({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Boom.
const
- M3EShapeContainer.bun({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Bun.
const
- M3EShapeContainer.burst({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Burst.
const
- M3EShapeContainer.circle({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Circle.
const
- M3EShapeContainer.clamShell({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Clam shell.
const
- M3EShapeContainer.clover4Leaf({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Four-leaf clover.
const
- M3EShapeContainer.clover8Leaf({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Eight-leaf clover.
const
-
Four-sided cookie.
const
-
Six-sided cookie.
const
-
Seven-sided cookie.
const
-
Nine-sided cookie.
const
-
Twelve-sided cookie.
const
- M3EShapeContainer.diamond({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Diamond.
const
- M3EShapeContainer.fan({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Fan.
const
- M3EShapeContainer.flower({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Flower.
const
- M3EShapeContainer.gem({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Gem.
const
- M3EShapeContainer.ghostish({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Ghostish.
const
- M3EShapeContainer.heart({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Heart.
const
- M3EShapeContainer.oval({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Oval.
const
- M3EShapeContainer.pentagon({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Pentagon.
const
- M3EShapeContainer.pill({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Pill.
const
- M3EShapeContainer.pixelCircle({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Pixel circle.
const
- M3EShapeContainer.pixelTriangle({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Pixel triangle.
const
- M3EShapeContainer.puffy({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Puffy.
const
- M3EShapeContainer.puffyDiamond({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Puffy diamond.
const
- M3EShapeContainer.semiCircle({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Semi-circle.
const
- M3EShapeContainer.slanted({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Slanted square.
const
- M3EShapeContainer.softBoom({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Soft boom.
const
- M3EShapeContainer.softBurst({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Soft burst.
const
- M3EShapeContainer.square({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Rounded square.
const
- M3EShapeContainer.sunny({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Sunny.
const
- M3EShapeContainer.triangle({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Triangle.
const
- M3EShapeContainer.verySunny({Key? key, Widget? child, double? width, double? height, Color? color, Gradient? gradient, Clip clipBehavior = Clip.antiAlias})
-
Very sunny.
const
Properties
- child → Widget?
-
Optional content inside the clip.
final
- clipBehavior → Clip
-
Clip quality.
final
- color → Color?
-
Fill color (ignored when gradient is set, except as a fallback).
final
- gradient → Gradient?
-
Fill gradient. Overrides color when both are set.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
Explicit height.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- kind → M3EShapeKind
-
Polygon kind.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double?
-
Explicit width.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited