M3ETappableInkScope class
Supplies ink interaction callbacks from the tappable primitive to overlays.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- ProxyWidget
- InheritedWidget
- M3ETappableInkScope
Constructors
-
M3ETappableInkScope({required Widget child, VoidCallback? onTap, VoidCallback? onLongPress, MouseCursor? mouseCursor, GestureTapDownCallback? onTapDown, GestureTapUpCallback? onTapUp, VoidCallback? onTapCancel, ValueChanged<
bool> ? onHover, Key? key}) -
Creates an ink-scope that forwards gesture callbacks to descendants.
const
Properties
- child → Widget
-
The widget below this widget in the tree.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInteractive → bool
-
Whether this scope has a tap or long-press handler.
no setter
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mouseCursor → MouseCursor?
-
Cursor shown while interactive.
final
-
onHover
→ ValueChanged<
bool> ? -
Called when the hover state changes.
final
- onLongPress → VoidCallback?
-
Called when the ink well is long-pressed.
final
- onTap → VoidCallback?
-
Called when the ink well is tapped.
final
- onTapCancel → VoidCallback?
-
Called when a tap gesture is canceled.
final
- onTapDown → GestureTapDownCallback?
-
Called when a pointer contacts the ink well.
final
- onTapUp → GestureTapUpCallback?
-
Called when a pointer that contacted the ink well stops contacting it.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → InheritedElement -
Inflates this configuration to a concrete instance.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
updateShouldNotify(
covariant M3ETappableInkScope oldWidget) → bool -
Whether dependents should rebuild when callbacks change.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
maybeOf(
BuildContext context) → M3ETappableInkScope? - Returns the nearest M3ETappableInkScope, if any.