M3EThemeExtension<T extends M3EThemeExtension<T> > class
abstract
Base type for overridable component themes registered on M3EThemeData.
- Implementers
- M3EAppBarTheme
- M3EBadgeTheme
- M3EBottomSheetTheme
- M3EButtonTheme
- M3ECardTheme
- M3ECarouselTheme
- M3ECheckboxTheme
- M3EChipTheme
- M3ECircularProgressTheme
- M3EDatePickerTheme
- M3EDialogTheme
- M3EDividerTheme
- M3EDropdownMenuTheme
- M3EFabMenuTheme
- M3EFabTheme
- M3EIconButtonTheme
- M3ELinearProgressTheme
- M3EListTheme
- M3ELoadingIndicatorTheme
- M3EMenuTheme
- M3ENavigationBarTheme
- M3ENavigationDrawerTheme
- M3ENavigationRailTheme
- M3EProgressIndicatorTheme
- M3ERadioTheme
- M3ERefreshIndicatorTheme
- M3ESearchBarTheme
- M3ESearchViewTheme
- M3ESegmentedButtonTheme
- M3ESideSheetTheme
- M3ESliderTheme
- M3ESnackbarTheme
- M3ESplitButtonTheme
- M3ESwitchTheme
- M3ETabTheme
- M3ETextFieldTheme
- M3ETimePickerTheme
- M3EToggleButtonGroupTheme
- M3EToggleButtonTheme
- M3EToolbarTheme
- M3ETooltipTheme
Constructors
- M3EThemeExtension()
-
Creates a theme extension.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
) → T - Returns a copy with non-null fields replaced.
-
lerp(
T? other, double t) → T -
Linearly interpolates between this theme and
other. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited