M3EButtonFontSize class

Per-size label font sizes for expressive buttons.

Mirrors the ButtonFontSize token from the m3e_design package.

Annotations

Constructors

M3EButtonFontSize({double xs = 14, double sm = 14, double md = 16, double lg = 20, double xl = 24})
Creates button label sizes for each expressive size step.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lg double
Large button label size.
final
md double
Medium button label size.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm double
Small button label size.
final
xl double
Extra-large button label size.
final
xs double
Extra-small button label size.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited